import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.AntiSpywareSignature("example", {});
 * ```
 */
export declare class AntiSpywareSignature extends pulumi.CustomResource {
    /**
     * Get an existing AntiSpywareSignature resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AntiSpywareSignatureState, opts?: pulumi.CustomResourceOptions): AntiSpywareSignature;
    /**
     * Returns true if the given object is an instance of AntiSpywareSignature.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AntiSpywareSignature;
    /**
     * The Bugtraqs param.
     */
    readonly bugtraqs: pulumi.Output<string[] | undefined>;
    /**
     * The Comment param. String length must not exceed 256 characters.
     */
    readonly comment: pulumi.Output<string | undefined>;
    /**
     * The Cves param.
     */
    readonly cves: pulumi.Output<string[] | undefined>;
    /**
     * The DefaultAction param.
     */
    readonly defaultAction: pulumi.Output<outputs.AntiSpywareSignatureDefaultAction | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Direction param. String must be one of these: `"client2server"`, `"server2client"`, `"both"`.
     */
    readonly direction: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The References param.
     */
    readonly references: pulumi.Output<string[] | undefined>;
    /**
     * The Severity param. String must be one of these: `"critical"`, `"low"`, `"high"`, `"medium"`, `"informational"`.
     */
    readonly severity: pulumi.Output<string | undefined>;
    /**
     * The Signature param.
     */
    readonly signature: pulumi.Output<outputs.AntiSpywareSignatureSignature | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * threat id range \n\n and \n\n. Value must be between 15000 and 70000000.
     */
    readonly threatId: pulumi.Output<number>;
    /**
     * The Threatname param. String length must not exceed 1024 characters.
     */
    readonly threatname: pulumi.Output<string>;
    /**
     * The Vendors param.
     */
    readonly vendors: pulumi.Output<string[] | undefined>;
    /**
     * Create a AntiSpywareSignature resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AntiSpywareSignatureArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AntiSpywareSignature resources.
 */
export interface AntiSpywareSignatureState {
    /**
     * The Bugtraqs param.
     */
    bugtraqs?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Comment param. String length must not exceed 256 characters.
     */
    comment?: pulumi.Input<string>;
    /**
     * The Cves param.
     */
    cves?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The DefaultAction param.
     */
    defaultAction?: pulumi.Input<inputs.AntiSpywareSignatureDefaultAction>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Direction param. String must be one of these: `"client2server"`, `"server2client"`, `"both"`.
     */
    direction?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The References param.
     */
    references?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Severity param. String must be one of these: `"critical"`, `"low"`, `"high"`, `"medium"`, `"informational"`.
     */
    severity?: pulumi.Input<string>;
    /**
     * The Signature param.
     */
    signature?: pulumi.Input<inputs.AntiSpywareSignatureSignature>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * threat id range \n\n and \n\n. Value must be between 15000 and 70000000.
     */
    threatId?: pulumi.Input<number>;
    /**
     * The Threatname param. String length must not exceed 1024 characters.
     */
    threatname?: pulumi.Input<string>;
    /**
     * The Vendors param.
     */
    vendors?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a AntiSpywareSignature resource.
 */
export interface AntiSpywareSignatureArgs {
    /**
     * The Bugtraqs param.
     */
    bugtraqs?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Comment param. String length must not exceed 256 characters.
     */
    comment?: pulumi.Input<string>;
    /**
     * The Cves param.
     */
    cves?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The DefaultAction param.
     */
    defaultAction?: pulumi.Input<inputs.AntiSpywareSignatureDefaultAction>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Direction param. String must be one of these: `"client2server"`, `"server2client"`, `"both"`.
     */
    direction?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The References param.
     */
    references?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Severity param. String must be one of these: `"critical"`, `"low"`, `"high"`, `"medium"`, `"informational"`.
     */
    severity?: pulumi.Input<string>;
    /**
     * The Signature param.
     */
    signature?: pulumi.Input<inputs.AntiSpywareSignatureSignature>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * threat id range \n\n and \n\n. Value must be between 15000 and 70000000.
     */
    threatId: pulumi.Input<number>;
    /**
     * The Threatname param. String length must not exceed 1024 characters.
     */
    threatname: pulumi.Input<string>;
    /**
     * The Vendors param.
     */
    vendors?: pulumi.Input<pulumi.Input<string>[]>;
}
