import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.AppOverrideRule("example", {});
 * ```
 */
export declare class AppOverrideRule extends pulumi.CustomResource {
    /**
     * Get an existing AppOverrideRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AppOverrideRuleState, opts?: pulumi.CustomResourceOptions): AppOverrideRule;
    /**
     * Returns true if the given object is an instance of AppOverrideRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AppOverrideRule;
    /**
     * The Application param.
     */
    readonly application: pulumi.Output<string>;
    /**
     * The Description param. String length must not exceed 1024 characters.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Destinations param.
     */
    readonly destinations: pulumi.Output<string[]>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Disabled param. Default: `false`.
     */
    readonly disabled: pulumi.Output<boolean>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The Froms param.
     */
    readonly froms: pulumi.Output<string[]>;
    /**
     * The GroupTag param.
     */
    readonly groupTag: pulumi.Output<string | undefined>;
    /**
     * The Name param. String length must not exceed 63 characters. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The NegateDestination param. Default: `false`.
     */
    readonly negateDestination: pulumi.Output<boolean>;
    /**
     * The NegateSource param. Default: `false`.
     */
    readonly negateSource: pulumi.Output<boolean>;
    /**
     * The Port param. Value must be between 0 and 65535.
     */
    readonly port: pulumi.Output<number>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    readonly position: pulumi.Output<string>;
    /**
     * The Protocol param. String must be one of these: `"tcp"`, `"udp"`.
     */
    readonly protocol: pulumi.Output<string>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * The Sources param.
     */
    readonly sources: pulumi.Output<string[]>;
    /**
     * The Tags param.
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The Tos param.
     */
    readonly tos: pulumi.Output<string[]>;
    /**
     * Create a AppOverrideRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AppOverrideRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AppOverrideRule resources.
 */
export interface AppOverrideRuleState {
    /**
     * The Application param.
     */
    application?: pulumi.Input<string>;
    /**
     * The Description param. String length must not exceed 1024 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The Destinations param.
     */
    destinations?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Disabled param. Default: `false`.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Froms param.
     */
    froms?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The GroupTag param.
     */
    groupTag?: pulumi.Input<string>;
    /**
     * The Name param. String length must not exceed 63 characters. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    name?: pulumi.Input<string>;
    /**
     * The NegateDestination param. Default: `false`.
     */
    negateDestination?: pulumi.Input<boolean>;
    /**
     * The NegateSource param. Default: `false`.
     */
    negateSource?: pulumi.Input<boolean>;
    /**
     * The Port param. Value must be between 0 and 65535.
     */
    port?: pulumi.Input<number>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    position?: pulumi.Input<string>;
    /**
     * The Protocol param. String must be one of these: `"tcp"`, `"udp"`.
     */
    protocol?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Sources param.
     */
    sources?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Tags param.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    tfid?: pulumi.Input<string>;
    /**
     * The Tos param.
     */
    tos?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a AppOverrideRule resource.
 */
export interface AppOverrideRuleArgs {
    /**
     * The Application param.
     */
    application: pulumi.Input<string>;
    /**
     * The Description param. String length must not exceed 1024 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The Destinations param.
     */
    destinations: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Disabled param. Default: `false`.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Froms param.
     */
    froms: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The GroupTag param.
     */
    groupTag?: pulumi.Input<string>;
    /**
     * The Name param. String length must not exceed 63 characters. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    name?: pulumi.Input<string>;
    /**
     * The NegateDestination param. Default: `false`.
     */
    negateDestination?: pulumi.Input<boolean>;
    /**
     * The NegateSource param. Default: `false`.
     */
    negateSource?: pulumi.Input<boolean>;
    /**
     * The Port param. Value must be between 0 and 65535.
     */
    port: pulumi.Input<number>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    position?: pulumi.Input<string>;
    /**
     * The Protocol param. String must be one of these: `"tcp"`, `"udp"`.
     */
    protocol: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Sources param.
     */
    sources: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Tags param.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Tos param.
     */
    tos: pulumi.Input<pulumi.Input<string>[]>;
}
