import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getHipObject({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getHipObject(args: GetHipObjectArgs, opts?: pulumi.InvokeOptions): Promise<GetHipObjectResult>;
/**
 * A collection of arguments for invoking getHipObject.
 */
export interface GetHipObjectArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getHipObject.
 */
export interface GetHipObjectResult {
    /**
     * The AntiMalware param.
     */
    readonly antiMalware: outputs.GetHipObjectAntiMalware;
    /**
     * The Certificate param.
     */
    readonly certificate: outputs.GetHipObjectCertificate;
    /**
     * The CustomChecks param.
     */
    readonly customChecks: outputs.GetHipObjectCustomChecks;
    /**
     * The DataLossPrevention param.
     */
    readonly dataLossPrevention: outputs.GetHipObjectDataLossPrevention;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    readonly description: string;
    /**
     * The DiskBackup param.
     */
    readonly diskBackup: outputs.GetHipObjectDiskBackup;
    /**
     * The DiskEncryption param.
     */
    readonly diskEncryption: outputs.GetHipObjectDiskEncryption;
    /**
     * The Firewall param.
     */
    readonly firewall: outputs.GetHipObjectFirewall;
    /**
     * The HostInfo param.
     */
    readonly hostInfo: outputs.GetHipObjectHostInfo;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The MobileDevice param.
     */
    readonly mobileDevice: outputs.GetHipObjectMobileDevice;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    readonly name: string;
    /**
     * The NetworkInfo param.
     */
    readonly networkInfo: outputs.GetHipObjectNetworkInfo;
    /**
     * The PatchManagement param.
     */
    readonly patchManagement: outputs.GetHipObjectPatchManagement;
    readonly tfid: string;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getHipObject({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getHipObjectOutput(args: GetHipObjectOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetHipObjectResult>;
/**
 * A collection of arguments for invoking getHipObject.
 */
export interface GetHipObjectOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
