import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getRadiusServerProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getRadiusServerProfile(args: GetRadiusServerProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetRadiusServerProfileResult>;
/**
 * A collection of arguments for invoking getRadiusServerProfile.
 */
export interface GetRadiusServerProfileArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getRadiusServerProfile.
 */
export interface GetRadiusServerProfileResult {
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The Protocol param.
     */
    readonly protocol: outputs.GetRadiusServerProfileProtocol;
    /**
     * The Retries param. Value must be between 1 and 5.
     */
    readonly retries: number;
    /**
     * The Servers param.
     */
    readonly servers: outputs.GetRadiusServerProfileServer[];
    readonly tfid: string;
    /**
     * The Timeout param. Value must be between 1 and 120.
     */
    readonly timeout: number;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getRadiusServerProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getRadiusServerProfileOutput(args: GetRadiusServerProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRadiusServerProfileResult>;
/**
 * A collection of arguments for invoking getRadiusServerProfile.
 */
export interface GetRadiusServerProfileOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
