import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getSamlServerProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getSamlServerProfile(args: GetSamlServerProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetSamlServerProfileResult>;
/**
 * A collection of arguments for invoking getSamlServerProfile.
 */
export interface GetSamlServerProfileArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getSamlServerProfile.
 */
export interface GetSamlServerProfileResult {
    /**
     * The Certificate param. String length must not exceed 63 characters.
     */
    readonly certificate: string;
    /**
     * The EntityId param. String length must be between 1 and 1024 characters.
     */
    readonly entityId: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The MaxClockSkew param. Value must be between 1 and 900.
     */
    readonly maxClockSkew: number;
    /**
     * The SloBindings param. String must be one of these: `"post"`, `"redirect"`.
     */
    readonly sloBindings: string;
    /**
     * The SsoBindings param. String must be one of these: `"post"`, `"redirect"`.
     */
    readonly ssoBindings: string;
    /**
     * The SsoUrl param. String length must be between 1 and 255 characters.
     */
    readonly ssoUrl: string;
    readonly tfid: string;
    /**
     * The ValidateIdpCertificate param.
     */
    readonly validateIdpCertificate: boolean;
    /**
     * The WantAuthRequestsSigned param.
     */
    readonly wantAuthRequestsSigned: boolean;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getSamlServerProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getSamlServerProfileOutput(args: GetSamlServerProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSamlServerProfileResult>;
/**
 * A collection of arguments for invoking getSamlServerProfile.
 */
export interface GetSamlServerProfileOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
