import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getServiceGroup({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getServiceGroup(args: GetServiceGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetServiceGroupResult>;
/**
 * A collection of arguments for invoking getServiceGroup.
 */
export interface GetServiceGroupArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getServiceGroup.
 */
export interface GetServiceGroupResult {
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The Members param. Individual elements in this list are subject to additional validation. String length must not exceed 63 characters.
     */
    readonly members: string[];
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    readonly name: string;
    /**
     * Tags for service group object. List must contain at most 64 elements. Individual elements in this list are subject to additional validation. String length must not exceed 127 characters.
     */
    readonly tags: string[];
    readonly tfid: string;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getServiceGroup({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getServiceGroupOutput(args: GetServiceGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetServiceGroupResult>;
/**
 * A collection of arguments for invoking getServiceGroup.
 */
export interface GetServiceGroupOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
