import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getTlsServiceProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getTlsServiceProfile(args: GetTlsServiceProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetTlsServiceProfileResult>;
/**
 * A collection of arguments for invoking getTlsServiceProfile.
 */
export interface GetTlsServiceProfileArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getTlsServiceProfile.
 */
export interface GetTlsServiceProfileResult {
    /**
     * SSL certificate file name. String length must not exceed 255 characters.
     */
    readonly certificate: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * SSL TLS Service Profile name, value is muCustomDomainSSLProfile when it is used on mobile-agent infra settings. String length must not exceed 127 characters. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    readonly name: string;
    /**
     * The ProtocolSettings param.
     */
    readonly protocolSettings: outputs.GetTlsServiceProfileProtocolSettings;
    readonly tfid: string;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getTlsServiceProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getTlsServiceProfileOutput(args: GetTlsServiceProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTlsServiceProfileResult>;
/**
 * A collection of arguments for invoking getTlsServiceProfile.
 */
export interface GetTlsServiceProfileOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
