import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a listing of config items.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getUrlFilteringCategoryList({
 *     folder: "Shared",
 * });
 * ```
 */
export declare function getUrlFilteringCategoryList(args?: GetUrlFilteringCategoryListArgs, opts?: pulumi.InvokeOptions): Promise<GetUrlFilteringCategoryListResult>;
/**
 * A collection of arguments for invoking getUrlFilteringCategoryList.
 */
export interface GetUrlFilteringCategoryListArgs {
    /**
     * The Device param.
     */
    device?: string;
    /**
     * The Folder param.
     */
    folder?: string;
    /**
     * The Limit param. A limit of -1 will return all configured items. Default: `200`.
     */
    limit?: number;
    /**
     * The Name param.
     */
    name?: string;
    /**
     * The Offset param. Default: `0`.
     */
    offset?: number;
    /**
     * The Snippet param.
     */
    snippet?: string;
}
/**
 * A collection of values returned by getUrlFilteringCategoryList.
 */
export interface GetUrlFilteringCategoryListResult {
    /**
     * The Data param.
     */
    readonly datas: outputs.GetUrlFilteringCategoryListData[];
    /**
     * The Device param.
     */
    readonly device?: string;
    /**
     * The Folder param.
     */
    readonly folder?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The Limit param. A limit of -1 will return all configured items. Default: `200`.
     */
    readonly limit: number;
    /**
     * The Name param.
     */
    readonly name?: string;
    /**
     * The Offset param. Default: `0`.
     */
    readonly offset: number;
    /**
     * The Snippet param.
     */
    readonly snippet?: string;
    readonly tfid: string;
    /**
     * The Total param.
     */
    readonly total: number;
}
/**
 * Retrieves a listing of config items.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getUrlFilteringCategoryList({
 *     folder: "Shared",
 * });
 * ```
 */
export declare function getUrlFilteringCategoryListOutput(args?: GetUrlFilteringCategoryListOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetUrlFilteringCategoryListResult>;
/**
 * A collection of arguments for invoking getUrlFilteringCategoryList.
 */
export interface GetUrlFilteringCategoryListOutputArgs {
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Limit param. A limit of -1 will return all configured items. Default: `200`.
     */
    limit?: pulumi.Input<number>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Offset param. Default: `0`.
     */
    offset?: pulumi.Input<number>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
}
