import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getVariable({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getVariable(args: GetVariableArgs, opts?: pulumi.InvokeOptions): Promise<GetVariableResult>;
/**
 * A collection of arguments for invoking getVariable.
 */
export interface GetVariableArgs {
    /**
     * The Device param.
     */
    device?: string;
    /**
     * The Folder param.
     */
    folder?: string;
    /**
     * The Id param.
     */
    id: string;
    /**
     * The Snippet param.
     */
    snippet?: string;
}
/**
 * A collection of values returned by getVariable.
 */
export interface GetVariableResult {
    /**
     * The Description param.
     */
    readonly description: string;
    /**
     * The Device param.
     */
    readonly device?: string;
    /**
     * The Folder param.
     */
    readonly folder?: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    readonly name: string;
    /**
     * The Overridden param.
     */
    readonly overridden: boolean;
    /**
     * The Snippet param.
     */
    readonly snippet?: string;
    readonly tfid: string;
    /**
     * The Type param. String must be one of these: `"percent"`, `"count"`, `"ip-netmask"`, `"zone"`, `"ip-range"`, `"ip-wildcard"`, `"device-priority"`, `"device-id"`, `"egress-max"`, `"as-number"`, `"fqdn"`, `"port"`, `"link-tag"`, `"group-id"`, `"rate"`, `"router-id"`, `"qos-profile"`, `"timer"`.
     */
    readonly type: string;
    /**
     * value can accept either string or integer.
     */
    readonly value: string;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getVariable({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getVariableOutput(args: GetVariableOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetVariableResult>;
/**
 * A collection of arguments for invoking getVariable.
 */
export interface GetVariableOutputArgs {
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
}
