import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 */
export declare class HipObject extends pulumi.CustomResource {
    /**
     * Get an existing HipObject resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: HipObjectState, opts?: pulumi.CustomResourceOptions): HipObject;
    /**
     * Returns true if the given object is an instance of HipObject.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is HipObject;
    /**
     * The AntiMalware param.
     */
    readonly antiMalware: pulumi.Output<outputs.HipObjectAntiMalware | undefined>;
    /**
     * The Certificate param.
     */
    readonly certificate: pulumi.Output<outputs.HipObjectCertificate | undefined>;
    /**
     * The CustomChecks param.
     */
    readonly customChecks: pulumi.Output<outputs.HipObjectCustomChecks | undefined>;
    /**
     * The DataLossPrevention param.
     */
    readonly dataLossPrevention: pulumi.Output<outputs.HipObjectDataLossPrevention | undefined>;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The DiskBackup param.
     */
    readonly diskBackup: pulumi.Output<outputs.HipObjectDiskBackup | undefined>;
    /**
     * The DiskEncryption param.
     */
    readonly diskEncryption: pulumi.Output<outputs.HipObjectDiskEncryption | undefined>;
    /**
     * The Firewall param.
     */
    readonly firewall: pulumi.Output<outputs.HipObjectFirewall | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The HostInfo param.
     */
    readonly hostInfo: pulumi.Output<outputs.HipObjectHostInfo | undefined>;
    /**
     * The MobileDevice param.
     */
    readonly mobileDevice: pulumi.Output<outputs.HipObjectMobileDevice | undefined>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The NetworkInfo param.
     */
    readonly networkInfo: pulumi.Output<outputs.HipObjectNetworkInfo | undefined>;
    /**
     * The PatchManagement param.
     */
    readonly patchManagement: pulumi.Output<outputs.HipObjectPatchManagement | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * Create a HipObject resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: HipObjectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering HipObject resources.
 */
export interface HipObjectState {
    /**
     * The AntiMalware param.
     */
    antiMalware?: pulumi.Input<inputs.HipObjectAntiMalware>;
    /**
     * The Certificate param.
     */
    certificate?: pulumi.Input<inputs.HipObjectCertificate>;
    /**
     * The CustomChecks param.
     */
    customChecks?: pulumi.Input<inputs.HipObjectCustomChecks>;
    /**
     * The DataLossPrevention param.
     */
    dataLossPrevention?: pulumi.Input<inputs.HipObjectDataLossPrevention>;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The DiskBackup param.
     */
    diskBackup?: pulumi.Input<inputs.HipObjectDiskBackup>;
    /**
     * The DiskEncryption param.
     */
    diskEncryption?: pulumi.Input<inputs.HipObjectDiskEncryption>;
    /**
     * The Firewall param.
     */
    firewall?: pulumi.Input<inputs.HipObjectFirewall>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The HostInfo param.
     */
    hostInfo?: pulumi.Input<inputs.HipObjectHostInfo>;
    /**
     * The MobileDevice param.
     */
    mobileDevice?: pulumi.Input<inputs.HipObjectMobileDevice>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The NetworkInfo param.
     */
    networkInfo?: pulumi.Input<inputs.HipObjectNetworkInfo>;
    /**
     * The PatchManagement param.
     */
    patchManagement?: pulumi.Input<inputs.HipObjectPatchManagement>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a HipObject resource.
 */
export interface HipObjectArgs {
    /**
     * The AntiMalware param.
     */
    antiMalware?: pulumi.Input<inputs.HipObjectAntiMalware>;
    /**
     * The Certificate param.
     */
    certificate?: pulumi.Input<inputs.HipObjectCertificate>;
    /**
     * The CustomChecks param.
     */
    customChecks?: pulumi.Input<inputs.HipObjectCustomChecks>;
    /**
     * The DataLossPrevention param.
     */
    dataLossPrevention?: pulumi.Input<inputs.HipObjectDataLossPrevention>;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The DiskBackup param.
     */
    diskBackup?: pulumi.Input<inputs.HipObjectDiskBackup>;
    /**
     * The DiskEncryption param.
     */
    diskEncryption?: pulumi.Input<inputs.HipObjectDiskEncryption>;
    /**
     * The Firewall param.
     */
    firewall?: pulumi.Input<inputs.HipObjectFirewall>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The HostInfo param.
     */
    hostInfo?: pulumi.Input<inputs.HipObjectHostInfo>;
    /**
     * The MobileDevice param.
     */
    mobileDevice?: pulumi.Input<inputs.HipObjectMobileDevice>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The NetworkInfo param.
     */
    networkInfo?: pulumi.Input<inputs.HipObjectNetworkInfo>;
    /**
     * The PatchManagement param.
     */
    patchManagement?: pulumi.Input<inputs.HipObjectPatchManagement>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
}
