import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.IpsecCryptoProfile("example", {});
 * ```
 */
export declare class IpsecCryptoProfile extends pulumi.CustomResource {
    /**
     * Get an existing IpsecCryptoProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IpsecCryptoProfileState, opts?: pulumi.CustomResourceOptions): IpsecCryptoProfile;
    /**
     * Returns true if the given object is an instance of IpsecCryptoProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IpsecCryptoProfile;
    /**
     * The Ah param. Ensure that only one of the following is specified: `ah`, `esp`
     */
    readonly ah: pulumi.Output<outputs.IpsecCryptoProfileAh | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * phase-2 DH group (PFS DH group). String must be one of these: `"no-pfs"`, `"group1"`, `"group2"`, `"group5"`, `"group14"`, `"group19"`, `"group20"`. Default: `"group2"`.
     */
    readonly dhGroup: pulumi.Output<string>;
    /**
     * The Esp param. Ensure that only one of the following is specified: `ah`, `esp`
     */
    readonly esp: pulumi.Output<outputs.IpsecCryptoProfileEsp | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The Lifesize param.
     */
    readonly lifesize: pulumi.Output<outputs.IpsecCryptoProfileLifesize | undefined>;
    /**
     * The Lifetime param.
     */
    readonly lifetime: pulumi.Output<outputs.IpsecCryptoProfileLifetime>;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * Create a IpsecCryptoProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IpsecCryptoProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering IpsecCryptoProfile resources.
 */
export interface IpsecCryptoProfileState {
    /**
     * The Ah param. Ensure that only one of the following is specified: `ah`, `esp`
     */
    ah?: pulumi.Input<inputs.IpsecCryptoProfileAh>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * phase-2 DH group (PFS DH group). String must be one of these: `"no-pfs"`, `"group1"`, `"group2"`, `"group5"`, `"group14"`, `"group19"`, `"group20"`. Default: `"group2"`.
     */
    dhGroup?: pulumi.Input<string>;
    /**
     * The Esp param. Ensure that only one of the following is specified: `ah`, `esp`
     */
    esp?: pulumi.Input<inputs.IpsecCryptoProfileEsp>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Lifesize param.
     */
    lifesize?: pulumi.Input<inputs.IpsecCryptoProfileLifesize>;
    /**
     * The Lifetime param.
     */
    lifetime?: pulumi.Input<inputs.IpsecCryptoProfileLifetime>;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a IpsecCryptoProfile resource.
 */
export interface IpsecCryptoProfileArgs {
    /**
     * The Ah param. Ensure that only one of the following is specified: `ah`, `esp`
     */
    ah?: pulumi.Input<inputs.IpsecCryptoProfileAh>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * phase-2 DH group (PFS DH group). String must be one of these: `"no-pfs"`, `"group1"`, `"group2"`, `"group5"`, `"group14"`, `"group19"`, `"group20"`. Default: `"group2"`.
     */
    dhGroup?: pulumi.Input<string>;
    /**
     * The Esp param. Ensure that only one of the following is specified: `ah`, `esp`
     */
    esp?: pulumi.Input<inputs.IpsecCryptoProfileEsp>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Lifesize param.
     */
    lifesize?: pulumi.Input<inputs.IpsecCryptoProfileLifesize>;
    /**
     * The Lifetime param.
     */
    lifetime: pulumi.Input<inputs.IpsecCryptoProfileLifetime>;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
}
