import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.QosPolicyRule("example", {});
 * ```
 */
export declare class QosPolicyRule extends pulumi.CustomResource {
    /**
     * Get an existing QosPolicyRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: QosPolicyRuleState, opts?: pulumi.CustomResourceOptions): QosPolicyRule;
    /**
     * Returns true if the given object is an instance of QosPolicyRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is QosPolicyRule;
    /**
     * The Action param.
     */
    readonly action: pulumi.Output<outputs.QosPolicyRuleAction>;
    /**
     * The Description param.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The DscpTos param.
     */
    readonly dscpTos: pulumi.Output<outputs.QosPolicyRuleDscpTos | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    readonly position: pulumi.Output<string>;
    /**
     * The Schedule param.
     */
    readonly schedule: pulumi.Output<string | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * Create a QosPolicyRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: QosPolicyRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering QosPolicyRule resources.
 */
export interface QosPolicyRuleState {
    /**
     * The Action param.
     */
    action?: pulumi.Input<inputs.QosPolicyRuleAction>;
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The DscpTos param.
     */
    dscpTos?: pulumi.Input<inputs.QosPolicyRuleDscpTos>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    position?: pulumi.Input<string>;
    /**
     * The Schedule param.
     */
    schedule?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a QosPolicyRule resource.
 */
export interface QosPolicyRuleArgs {
    /**
     * The Action param.
     */
    action: pulumi.Input<inputs.QosPolicyRuleAction>;
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The DscpTos param.
     */
    dscpTos?: pulumi.Input<inputs.QosPolicyRuleDscpTos>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    position?: pulumi.Input<string>;
    /**
     * The Schedule param.
     */
    schedule?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
}
