import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.ScepProfile("example", {});
 * ```
 */
export declare class ScepProfile extends pulumi.CustomResource {
    /**
     * Get an existing ScepProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ScepProfileState, opts?: pulumi.CustomResourceOptions): ScepProfile;
    /**
     * Returns true if the given object is an instance of ScepProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ScepProfile;
    /**
     * The Algorithm param.
     */
    readonly algorithm: pulumi.Output<outputs.ScepProfileAlgorithm | undefined>;
    /**
     * The CaIdentityName param.
     */
    readonly caIdentityName: pulumi.Output<string>;
    /**
     * The CertificateAttributes param.
     */
    readonly certificateAttributes: pulumi.Output<outputs.ScepProfileCertificateAttributes | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Digest param.
     */
    readonly digest: pulumi.Output<string>;
    /**
     * (Internal use) Encrypted values returned from the API.
     */
    readonly encryptedValues: pulumi.Output<{
        [key: string]: string;
    }>;
    /**
     * The Fingerprint param.
     */
    readonly fingerprint: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ScepCaCert param.
     */
    readonly scepCaCert: pulumi.Output<string | undefined>;
    /**
     * The ScepChallenge param.
     */
    readonly scepChallenge: pulumi.Output<outputs.ScepProfileScepChallenge | undefined>;
    /**
     * The ScepClientCert param.
     */
    readonly scepClientCert: pulumi.Output<string | undefined>;
    /**
     * The ScepUrl param.
     */
    readonly scepUrl: pulumi.Output<string>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * The Subject param.
     */
    readonly subject: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The UseAsDigitalSignature param.
     */
    readonly useAsDigitalSignature: pulumi.Output<boolean | undefined>;
    /**
     * The UseForKeyEncipherment param.
     */
    readonly useForKeyEncipherment: pulumi.Output<boolean | undefined>;
    /**
     * Create a ScepProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ScepProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ScepProfile resources.
 */
export interface ScepProfileState {
    /**
     * The Algorithm param.
     */
    algorithm?: pulumi.Input<inputs.ScepProfileAlgorithm>;
    /**
     * The CaIdentityName param.
     */
    caIdentityName?: pulumi.Input<string>;
    /**
     * The CertificateAttributes param.
     */
    certificateAttributes?: pulumi.Input<inputs.ScepProfileCertificateAttributes>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Digest param.
     */
    digest?: pulumi.Input<string>;
    /**
     * (Internal use) Encrypted values returned from the API.
     */
    encryptedValues?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The Fingerprint param.
     */
    fingerprint?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The ScepCaCert param.
     */
    scepCaCert?: pulumi.Input<string>;
    /**
     * The ScepChallenge param.
     */
    scepChallenge?: pulumi.Input<inputs.ScepProfileScepChallenge>;
    /**
     * The ScepClientCert param.
     */
    scepClientCert?: pulumi.Input<string>;
    /**
     * The ScepUrl param.
     */
    scepUrl?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Subject param.
     */
    subject?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * The UseAsDigitalSignature param.
     */
    useAsDigitalSignature?: pulumi.Input<boolean>;
    /**
     * The UseForKeyEncipherment param.
     */
    useForKeyEncipherment?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a ScepProfile resource.
 */
export interface ScepProfileArgs {
    /**
     * The Algorithm param.
     */
    algorithm?: pulumi.Input<inputs.ScepProfileAlgorithm>;
    /**
     * The CaIdentityName param.
     */
    caIdentityName: pulumi.Input<string>;
    /**
     * The CertificateAttributes param.
     */
    certificateAttributes?: pulumi.Input<inputs.ScepProfileCertificateAttributes>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Digest param.
     */
    digest: pulumi.Input<string>;
    /**
     * The Fingerprint param.
     */
    fingerprint?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The ScepCaCert param.
     */
    scepCaCert?: pulumi.Input<string>;
    /**
     * The ScepChallenge param.
     */
    scepChallenge?: pulumi.Input<inputs.ScepProfileScepChallenge>;
    /**
     * The ScepClientCert param.
     */
    scepClientCert?: pulumi.Input<string>;
    /**
     * The ScepUrl param.
     */
    scepUrl: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Subject param.
     */
    subject?: pulumi.Input<string>;
    /**
     * The UseAsDigitalSignature param.
     */
    useAsDigitalSignature?: pulumi.Input<boolean>;
    /**
     * The UseForKeyEncipherment param.
     */
    useForKeyEncipherment?: pulumi.Input<boolean>;
}
