import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.TrafficSteeringRule("example", {folder: "Shared"});
 * ```
 */
export declare class TrafficSteeringRule extends pulumi.CustomResource {
    /**
     * Get an existing TrafficSteeringRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: TrafficSteeringRuleState, opts?: pulumi.CustomResourceOptions): TrafficSteeringRule;
    /**
     * Returns true if the given object is an instance of TrafficSteeringRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TrafficSteeringRule;
    /**
     * The Action param.
     */
    readonly action: pulumi.Output<outputs.TrafficSteeringRuleAction | undefined>;
    /**
     * The Category param.
     */
    readonly categories: pulumi.Output<string[] | undefined>;
    /**
     * The Destination param.
     */
    readonly destinations: pulumi.Output<string[] | undefined>;
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    readonly folder: pulumi.Output<string>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Service param.
     */
    readonly services: pulumi.Output<string[]>;
    /**
     * The SourceUser param.
     */
    readonly sourceUsers: pulumi.Output<string[] | undefined>;
    /**
     * The Source param.
     */
    readonly sources: pulumi.Output<string[]>;
    readonly tfid: pulumi.Output<string>;
    /**
     * Create a TrafficSteeringRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TrafficSteeringRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering TrafficSteeringRule resources.
 */
export interface TrafficSteeringRuleState {
    /**
     * The Action param.
     */
    action?: pulumi.Input<inputs.TrafficSteeringRuleAction>;
    /**
     * The Category param.
     */
    categories?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Destination param.
     */
    destinations?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Service param.
     */
    services?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The SourceUser param.
     */
    sourceUsers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Source param.
     */
    sources?: pulumi.Input<pulumi.Input<string>[]>;
    tfid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a TrafficSteeringRule resource.
 */
export interface TrafficSteeringRuleArgs {
    /**
     * The Action param.
     */
    action?: pulumi.Input<inputs.TrafficSteeringRuleAction>;
    /**
     * The Category param.
     */
    categories?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Destination param.
     */
    destinations?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Service param.
     */
    services: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The SourceUser param.
     */
    sourceUsers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Source param.
     */
    sources: pulumi.Input<pulumi.Input<string>[]>;
}
