import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getVulnerabilityProtectionSignatures({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getVulnerabilityProtectionSignatures(args: GetVulnerabilityProtectionSignaturesArgs, opts?: pulumi.InvokeOptions): Promise<GetVulnerabilityProtectionSignaturesResult>;
/**
 * A collection of arguments for invoking getVulnerabilityProtectionSignatures.
 */
export interface GetVulnerabilityProtectionSignaturesArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getVulnerabilityProtectionSignatures.
 */
export interface GetVulnerabilityProtectionSignaturesResult {
    /**
     * The AffectedHost param.
     */
    readonly affectedHost: outputs.GetVulnerabilityProtectionSignaturesAffectedHost;
    /**
     * The Bugtraqs param.
     */
    readonly bugtraqs: string[];
    /**
     * The Comment param. String length must not exceed 256 characters.
     */
    readonly comment: string;
    /**
     * The Cves param.
     */
    readonly cves: string[];
    /**
     * The DefaultAction param.
     */
    readonly defaultAction: outputs.GetVulnerabilityProtectionSignaturesDefaultAction;
    /**
     * The Direction param. String must be one of these: `"client2server"`, `"server2client"`, `"both"`.
     */
    readonly direction: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The References param.
     */
    readonly references: string[];
    /**
     * The Severity param. String must be one of these: `"critical"`, `"low"`, `"high"`, `"medium"`, `"informational"`.
     */
    readonly severity: string;
    /**
     * The Signature param.
     */
    readonly signature: outputs.GetVulnerabilityProtectionSignaturesSignature;
    readonly tfid: string;
    /**
     * threat id range \n\n and \n\n. Value must be between 41000 and 6900000.
     */
    readonly threatId: number;
    /**
     * The Threatname param. String length must not exceed 1024 characters.
     */
    readonly threatname: string;
    /**
     * The Vendors param.
     */
    readonly vendors: string[];
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getVulnerabilityProtectionSignatures({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getVulnerabilityProtectionSignaturesOutput(args: GetVulnerabilityProtectionSignaturesOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetVulnerabilityProtectionSignaturesResult>;
/**
 * A collection of arguments for invoking getVulnerabilityProtectionSignatures.
 */
export interface GetVulnerabilityProtectionSignaturesOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
