import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
export interface AddressGroupDynamicValue {
    /**
     * Tag based filter defining group membership e.g. `tag1 AND tag2 OR tag3`. String length must not exceed 2047 characters.
     */
    filter: pulumi.Input<string>;
}
export interface AntiSpywareProfileMicaEngineSpywareEnabledList {
    /**
     * The InlinePolicyAction param. String must be one of these: `"alert"`, `"allow"`, `"drop"`, `"reset-both"`, `"reset-client"`, `"reset-server"`. Default: `"alert"`.
     */
    inlinePolicyAction?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
}
export interface AntiSpywareProfileRule {
    /**
     * The Action param.
     */
    action?: pulumi.Input<inputs.AntiSpywareProfileRuleAction>;
    /**
     * The Category param. String must be one of these: `"dns-proxy"`, `"backdoor"`, `"data-theft"`, `"autogen"`, `"spyware"`, `"dns-security"`, `"downloader"`, `"dns-phishing"`, `"phishing-kit"`, `"cryptominer"`, `"hacktool"`, `"dns-benign"`, `"dns-wildfire"`, `"botnet"`, `"dns-grayware"`, `"inline-cloud-c2"`, `"keylogger"`, `"p2p-communication"`, `"domain-edl"`, `"webshell"`, `"command-and-control"`, `"dns-ddns"`, `"net-worm"`, `"any"`, `"tls-fingerprint"`, `"dns-new-domain"`, `"dns"`, `"fraud"`, `"dns-c2"`, `"adware"`, `"post-exploitation"`, `"dns-malware"`, `"browser-hijack"`, `"dns-parked"`.
     */
    category?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The PacketCapture param. String must be one of these: `"disable"`, `"single-packet"`, `"extended-capture"`.
     */
    packetCapture?: pulumi.Input<string>;
    /**
     * The Severities param.
     */
    severities?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ThreatName param. String length must exceed 4 characters.
     */
    threatName?: pulumi.Input<string>;
}
export interface AntiSpywareProfileRuleAction {
    /**
     * The Alert param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    alert?: pulumi.Input<boolean>;
    /**
     * The Allow param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    allow?: pulumi.Input<boolean>;
    /**
     * The BlockIp param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    blockIp?: pulumi.Input<inputs.AntiSpywareProfileRuleActionBlockIp>;
    /**
     * The Drop param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    drop?: pulumi.Input<boolean>;
    /**
     * The ResetBoth param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetBoth?: pulumi.Input<boolean>;
    /**
     * The ResetClient param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetClient?: pulumi.Input<boolean>;
    /**
     * The ResetServer param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetServer?: pulumi.Input<boolean>;
}
export interface AntiSpywareProfileRuleActionBlockIp {
    /**
     * The Duration param. Value must be between 1 and 3600.
     */
    duration?: pulumi.Input<number>;
    /**
     * The TrackBy param. String must be one of these: `"source-and-destination"`, `"source"`.
     */
    trackBy?: pulumi.Input<string>;
}
export interface AntiSpywareProfileThreatException {
    /**
     * The Action param.
     */
    action?: pulumi.Input<inputs.AntiSpywareProfileThreatExceptionAction>;
    /**
     * The ExemptIps param.
     */
    exemptIps?: pulumi.Input<pulumi.Input<inputs.AntiSpywareProfileThreatExceptionExemptIp>[]>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Notes param.
     */
    notes?: pulumi.Input<string>;
    /**
     * The PacketCapture param. String must be one of these: `"disable"`, `"single-packet"`, `"extended-capture"`.
     */
    packetCapture?: pulumi.Input<string>;
}
export interface AntiSpywareProfileThreatExceptionAction {
    /**
     * The Alert param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    alert?: pulumi.Input<boolean>;
    /**
     * The Allow param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    allow?: pulumi.Input<boolean>;
    /**
     * The BlockIp param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    blockIp?: pulumi.Input<inputs.AntiSpywareProfileThreatExceptionActionBlockIp>;
    /**
     * The Default param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    default?: pulumi.Input<boolean>;
    /**
     * The Drop param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    drop?: pulumi.Input<boolean>;
    /**
     * The ResetBoth param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetBoth?: pulumi.Input<boolean>;
    /**
     * The ResetClient param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetClient?: pulumi.Input<boolean>;
    /**
     * The ResetServer param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetServer?: pulumi.Input<boolean>;
}
export interface AntiSpywareProfileThreatExceptionActionBlockIp {
    /**
     * The Duration param. Value must be between 1 and 3600.
     */
    duration?: pulumi.Input<number>;
    /**
     * The TrackBy param. String must be one of these: `"source-and-destination"`, `"source"`.
     */
    trackBy?: pulumi.Input<string>;
}
export interface AntiSpywareProfileThreatExceptionExemptIp {
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
}
export interface AntiSpywareSignatureDefaultAction {
    /**
     * The Alert param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    alert?: pulumi.Input<boolean>;
    /**
     * The Allow param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    allow?: pulumi.Input<boolean>;
    /**
     * The BlockIp param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    blockIp?: pulumi.Input<inputs.AntiSpywareSignatureDefaultActionBlockIp>;
    /**
     * The Drop param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    drop?: pulumi.Input<boolean>;
    /**
     * The ResetBoth param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetBoth?: pulumi.Input<boolean>;
    /**
     * The ResetClient param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetClient?: pulumi.Input<boolean>;
    /**
     * The ResetServer param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetServer?: pulumi.Input<boolean>;
}
export interface AntiSpywareSignatureDefaultActionBlockIp {
    /**
     * The Duration param. Value must be between 1 and 3600.
     */
    duration?: pulumi.Input<number>;
    /**
     * The TrackBy param. String must be one of these: `"source-and-destination"`, `"source"`.
     */
    trackBy?: pulumi.Input<string>;
}
export interface AntiSpywareSignatureSignature {
    /**
     * The Combination param. Ensure that only one of the following is specified: `combination`, `standard`
     */
    combination?: pulumi.Input<inputs.AntiSpywareSignatureSignatureCombination>;
    /**
     * The Standards param. Ensure that only one of the following is specified: `combination`, `standard`
     */
    standards?: pulumi.Input<pulumi.Input<inputs.AntiSpywareSignatureSignatureStandard>[]>;
}
export interface AntiSpywareSignatureSignatureCombination {
    /**
     * The AndConditions param.
     */
    andConditions?: pulumi.Input<pulumi.Input<inputs.AntiSpywareSignatureSignatureCombinationAndCondition>[]>;
    /**
     * The OrderFree param. Default: `false`.
     */
    orderFree?: pulumi.Input<boolean>;
    /**
     * The TimeAttribute param.
     */
    timeAttribute?: pulumi.Input<inputs.AntiSpywareSignatureSignatureCombinationTimeAttribute>;
}
export interface AntiSpywareSignatureSignatureCombinationAndCondition {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The OrConditions param.
     */
    orConditions?: pulumi.Input<pulumi.Input<inputs.AntiSpywareSignatureSignatureCombinationAndConditionOrCondition>[]>;
}
export interface AntiSpywareSignatureSignatureCombinationAndConditionOrCondition {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The ThreatId param.
     */
    threatId?: pulumi.Input<string>;
}
export interface AntiSpywareSignatureSignatureCombinationTimeAttribute {
    /**
     * The Interval param. Value must be between 1 and 3600.
     */
    interval?: pulumi.Input<number>;
    /**
     * The Threshold param. Value must be between 1 and 255.
     */
    threshold?: pulumi.Input<number>;
    /**
     * The TrackBy param. String must be one of these: `"source-and-destination"`, `"source"`, `"destination"`.
     */
    trackBy?: pulumi.Input<string>;
}
export interface AntiSpywareSignatureSignatureStandard {
    /**
     * The AndConditions param.
     */
    andConditions?: pulumi.Input<pulumi.Input<inputs.AntiSpywareSignatureSignatureStandardAndCondition>[]>;
    /**
     * The Comment param. String length must not exceed 256 characters.
     */
    comment?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
    /**
     * The OrderFree param. Default: `false`.
     */
    orderFree?: pulumi.Input<boolean>;
    /**
     * The Scope param. String must be one of these: `"protocol-data-unit"`, `"session"`.
     */
    scope?: pulumi.Input<string>;
}
export interface AntiSpywareSignatureSignatureStandardAndCondition {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The OrConditions param.
     */
    orConditions?: pulumi.Input<pulumi.Input<inputs.AntiSpywareSignatureSignatureStandardAndConditionOrCondition>[]>;
}
export interface AntiSpywareSignatureSignatureStandardAndConditionOrCondition {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Operator param.
     */
    operator?: pulumi.Input<inputs.AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperator>;
}
export interface AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperator {
    /**
     * The EqualTo param.
     */
    equalTo?: pulumi.Input<inputs.AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorEqualTo>;
    /**
     * The GreaterThan param.
     */
    greaterThan?: pulumi.Input<inputs.AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorGreaterThan>;
    /**
     * The LessThan param.
     */
    lessThan?: pulumi.Input<inputs.AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorLessThan>;
    /**
     * The PatternMatch param.
     */
    patternMatch?: pulumi.Input<inputs.AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorPatternMatch>;
}
export interface AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorEqualTo {
    /**
     * The Context param.
     */
    context?: pulumi.Input<string>;
    /**
     * The Negate param. Default: `false`.
     */
    negate?: pulumi.Input<boolean>;
    /**
     * The Qualifiers param.
     */
    qualifiers?: pulumi.Input<pulumi.Input<inputs.AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorEqualToQualifier>[]>;
    /**
     * The Value param. Value must be between 0 and 4294967295.
     */
    value?: pulumi.Input<number>;
}
export interface AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorEqualToQualifier {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Value param.
     */
    value?: pulumi.Input<string>;
}
export interface AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorGreaterThan {
    /**
     * The Context param.
     */
    context?: pulumi.Input<string>;
    /**
     * The Qualifiers param.
     */
    qualifiers?: pulumi.Input<pulumi.Input<inputs.AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorGreaterThanQualifier>[]>;
    /**
     * The Value param. Value must be between 0 and 4294967295.
     */
    value?: pulumi.Input<number>;
}
export interface AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorGreaterThanQualifier {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Value param.
     */
    value?: pulumi.Input<string>;
}
export interface AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorLessThan {
    /**
     * The Context param.
     */
    context?: pulumi.Input<string>;
    /**
     * The Qualifiers param.
     */
    qualifiers?: pulumi.Input<pulumi.Input<inputs.AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorLessThanQualifier>[]>;
    /**
     * The Value param. Value must be between 0 and 4294967295.
     */
    value?: pulumi.Input<number>;
}
export interface AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorLessThanQualifier {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Value param.
     */
    value?: pulumi.Input<string>;
}
export interface AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorPatternMatch {
    /**
     * The Context param.
     */
    context?: pulumi.Input<string>;
    /**
     * The Negate param. Default: `false`.
     */
    negate?: pulumi.Input<boolean>;
    /**
     * The Pattern param.
     */
    pattern?: pulumi.Input<string>;
    /**
     * The Qualifiers param.
     */
    qualifiers?: pulumi.Input<pulumi.Input<inputs.AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorPatternMatchQualifier>[]>;
}
export interface AntiSpywareSignatureSignatureStandardAndConditionOrConditionOperatorPatternMatchQualifier {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Value param.
     */
    value?: pulumi.Input<string>;
}
export interface ApplicationDefault {
    /**
     * The IdentByIcmp6Type param. Ensure that only one of the following is specified: `identByIcmp6Type`, `identByIcmpType`, `identByIpProtocol`, `port`
     */
    identByIcmp6Type?: pulumi.Input<inputs.ApplicationDefaultIdentByIcmp6Type>;
    /**
     * The IdentByIcmpType param. Ensure that only one of the following is specified: `identByIcmp6Type`, `identByIcmpType`, `identByIpProtocol`, `port`
     */
    identByIcmpType?: pulumi.Input<inputs.ApplicationDefaultIdentByIcmpType>;
    /**
     * The IdentByIpProtocol param. Ensure that only one of the following is specified: `identByIcmp6Type`, `identByIcmpType`, `identByIpProtocol`, `port`
     */
    identByIpProtocol?: pulumi.Input<string>;
    /**
     * The Ports param. Individual elements in this list are subject to additional validation. String length must not exceed 63 characters. Ensure that only one of the following is specified: `identByIcmp6Type`, `identByIcmpType`, `identByIpProtocol`, `port`
     */
    ports?: pulumi.Input<pulumi.Input<string>[]>;
}
export interface ApplicationDefaultIdentByIcmp6Type {
    /**
     * The Code param.
     */
    code?: pulumi.Input<string>;
    /**
     * The Type param.
     */
    type: pulumi.Input<string>;
}
export interface ApplicationDefaultIdentByIcmpType {
    /**
     * The Code param.
     */
    code?: pulumi.Input<string>;
    /**
     * The Type param.
     */
    type: pulumi.Input<string>;
}
export interface ApplicationFilterTagging {
    /**
     * The NoTag param. Ensure that only one of the following is specified: `noTag`, `tag`
     */
    noTag?: pulumi.Input<boolean>;
    /**
     * The Tags param. Individual elements in this list are subject to additional validation. String length must not exceed 127 characters. Ensure that only one of the following is specified: `noTag`, `tag`
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
}
export interface ApplicationSignature {
    /**
     * The AndConditions param.
     */
    andConditions?: pulumi.Input<pulumi.Input<inputs.ApplicationSignatureAndCondition>[]>;
    /**
     * The Comment param. String length must not exceed 256 characters.
     */
    comment?: pulumi.Input<string>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name: pulumi.Input<string>;
    /**
     * The OrderFree param. Default: `false`.
     */
    orderFree?: pulumi.Input<boolean>;
    /**
     * The Scope param. String must be one of these: `"protocol-data-unit"`, `"session"`. Default: `"protocol-data-unit"`.
     */
    scope?: pulumi.Input<string>;
}
export interface ApplicationSignatureAndCondition {
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name: pulumi.Input<string>;
    /**
     * The OrConditions param.
     */
    orConditions?: pulumi.Input<pulumi.Input<inputs.ApplicationSignatureAndConditionOrCondition>[]>;
}
export interface ApplicationSignatureAndConditionOrCondition {
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name: pulumi.Input<string>;
    /**
     * The Operator param.
     */
    operator: pulumi.Input<inputs.ApplicationSignatureAndConditionOrConditionOperator>;
}
export interface ApplicationSignatureAndConditionOrConditionOperator {
    /**
     * The EqualTo param. Ensure that only one of the following is specified: `equalTo`, `greaterThan`, `lessThan`, `patternMatch`
     */
    equalTo?: pulumi.Input<inputs.ApplicationSignatureAndConditionOrConditionOperatorEqualTo>;
    /**
     * The GreaterThan param. Ensure that only one of the following is specified: `equalTo`, `greaterThan`, `lessThan`, `patternMatch`
     */
    greaterThan?: pulumi.Input<inputs.ApplicationSignatureAndConditionOrConditionOperatorGreaterThan>;
    /**
     * The LessThan param. Ensure that only one of the following is specified: `equalTo`, `greaterThan`, `lessThan`, `patternMatch`
     */
    lessThan?: pulumi.Input<inputs.ApplicationSignatureAndConditionOrConditionOperatorLessThan>;
    /**
     * The PatternMatch param. Ensure that only one of the following is specified: `equalTo`, `greaterThan`, `lessThan`, `patternMatch`
     */
    patternMatch?: pulumi.Input<inputs.ApplicationSignatureAndConditionOrConditionOperatorPatternMatch>;
}
export interface ApplicationSignatureAndConditionOrConditionOperatorEqualTo {
    /**
     * The Context param.
     */
    context: pulumi.Input<string>;
    /**
     * 4-byte hex value. String length must not exceed 10 characters. String validation regex: `^[0][xX][0-9A-Fa-f]{8}$`.
     */
    mask?: pulumi.Input<string>;
    /**
     * The Position param. String length must not exceed 127 characters.
     */
    position?: pulumi.Input<string>;
    /**
     * The Value param. String length must not exceed 10 characters.
     */
    value: pulumi.Input<string>;
}
export interface ApplicationSignatureAndConditionOrConditionOperatorGreaterThan {
    /**
     * The Context param. String length must not exceed 127 characters.
     */
    context: pulumi.Input<string>;
    /**
     * The Qualifiers param.
     */
    qualifiers?: pulumi.Input<pulumi.Input<inputs.ApplicationSignatureAndConditionOrConditionOperatorGreaterThanQualifier>[]>;
    /**
     * The Value param. Value must be between 0 and 4294967295.
     */
    value: pulumi.Input<number>;
}
export interface ApplicationSignatureAndConditionOrConditionOperatorGreaterThanQualifier {
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name: pulumi.Input<string>;
    /**
     * The Value param.
     */
    value: pulumi.Input<string>;
}
export interface ApplicationSignatureAndConditionOrConditionOperatorLessThan {
    /**
     * The Context param. String length must not exceed 127 characters.
     */
    context: pulumi.Input<string>;
    /**
     * The Qualifiers param.
     */
    qualifiers?: pulumi.Input<pulumi.Input<inputs.ApplicationSignatureAndConditionOrConditionOperatorLessThanQualifier>[]>;
    /**
     * The Value param. Value must be between 0 and 4294967295.
     */
    value: pulumi.Input<number>;
}
export interface ApplicationSignatureAndConditionOrConditionOperatorLessThanQualifier {
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name: pulumi.Input<string>;
    /**
     * The Value param.
     */
    value: pulumi.Input<string>;
}
export interface ApplicationSignatureAndConditionOrConditionOperatorPatternMatch {
    /**
     * The Context param. String length must not exceed 127 characters.
     */
    context: pulumi.Input<string>;
    /**
     * The Pattern param. String length must not exceed 127 characters.
     */
    pattern: pulumi.Input<string>;
    /**
     * The Qualifiers param.
     */
    qualifiers?: pulumi.Input<pulumi.Input<inputs.ApplicationSignatureAndConditionOrConditionOperatorPatternMatchQualifier>[]>;
}
export interface ApplicationSignatureAndConditionOrConditionOperatorPatternMatchQualifier {
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name: pulumi.Input<string>;
    /**
     * The Value param.
     */
    value: pulumi.Input<string>;
}
export interface AuthenticationProfileLockout {
    /**
     * The FailedAttempts param. Value must be between 0 and 10.
     */
    failedAttempts?: pulumi.Input<number>;
    /**
     * The LockoutTime param. Value must be between 0 and 60.
     */
    lockoutTime?: pulumi.Input<number>;
}
export interface AuthenticationProfileMethod {
    /**
     * The Cloud param. Ensure that only one of the following is specified: `cloud`, `kerberos`, `ldap`, `localDatabase`, `radius`, `samlIdp`, `tacplus`
     */
    cloud?: pulumi.Input<inputs.AuthenticationProfileMethodCloud>;
    /**
     * The Kerberos param. Ensure that only one of the following is specified: `cloud`, `kerberos`, `ldap`, `localDatabase`, `radius`, `samlIdp`, `tacplus`
     */
    kerberos?: pulumi.Input<inputs.AuthenticationProfileMethodKerberos>;
    /**
     * The Ldap param. Ensure that only one of the following is specified: `cloud`, `kerberos`, `ldap`, `localDatabase`, `radius`, `samlIdp`, `tacplus`
     */
    ldap?: pulumi.Input<inputs.AuthenticationProfileMethodLdap>;
    /**
     * The LocalDatabase param. Ensure that only one of the following is specified: `cloud`, `kerberos`, `ldap`, `localDatabase`, `radius`, `samlIdp`, `tacplus`
     */
    localDatabase?: pulumi.Input<boolean>;
    /**
     * The Radius param. Ensure that only one of the following is specified: `cloud`, `kerberos`, `ldap`, `localDatabase`, `radius`, `samlIdp`, `tacplus`
     */
    radius?: pulumi.Input<inputs.AuthenticationProfileMethodRadius>;
    /**
     * The SamlIdp param. Ensure that only one of the following is specified: `cloud`, `kerberos`, `ldap`, `localDatabase`, `radius`, `samlIdp`, `tacplus`
     */
    samlIdp?: pulumi.Input<inputs.AuthenticationProfileMethodSamlIdp>;
    /**
     * The Tacplus param. Ensure that only one of the following is specified: `cloud`, `kerberos`, `ldap`, `localDatabase`, `radius`, `samlIdp`, `tacplus`
     */
    tacplus?: pulumi.Input<inputs.AuthenticationProfileMethodTacplus>;
}
export interface AuthenticationProfileMethodCloud {
    /**
     * The tenant profile name.
     */
    profileName?: pulumi.Input<string>;
}
export interface AuthenticationProfileMethodKerberos {
    /**
     * The Realm param.
     */
    realm?: pulumi.Input<string>;
    /**
     * The ServerProfile param.
     */
    serverProfile?: pulumi.Input<string>;
}
export interface AuthenticationProfileMethodLdap {
    /**
     * The LoginAttribute param.
     */
    loginAttribute?: pulumi.Input<string>;
    /**
     * The PasswdExpDays param.
     */
    passwdExpDays?: pulumi.Input<number>;
    /**
     * The ServerProfile param.
     */
    serverProfile?: pulumi.Input<string>;
}
export interface AuthenticationProfileMethodRadius {
    /**
     * The Checkgroup param.
     */
    checkgroup?: pulumi.Input<boolean>;
    /**
     * The ServerProfile param.
     */
    serverProfile?: pulumi.Input<string>;
}
export interface AuthenticationProfileMethodSamlIdp {
    /**
     * The AttributeNameUsergroup param. String length must be between 1 and 63 characters.
     */
    attributeNameUsergroup?: pulumi.Input<string>;
    /**
     * The AttributeNameUsername param. String length must be between 1 and 63 characters.
     */
    attributeNameUsername?: pulumi.Input<string>;
    /**
     * The CertificateProfile param. String length must not exceed 31 characters.
     */
    certificateProfile?: pulumi.Input<string>;
    /**
     * The EnableSingleLogout param.
     */
    enableSingleLogout?: pulumi.Input<boolean>;
    /**
     * The RequestSigningCertificate param. String length must not exceed 64 characters.
     */
    requestSigningCertificate?: pulumi.Input<string>;
    /**
     * The ServerProfile param. String length must not exceed 63 characters.
     */
    serverProfile?: pulumi.Input<string>;
}
export interface AuthenticationProfileMethodTacplus {
    /**
     * The Checkgroup param.
     */
    checkgroup?: pulumi.Input<boolean>;
    /**
     * The ServerProfile param.
     */
    serverProfile?: pulumi.Input<string>;
}
export interface AuthenticationProfileMultiFactorAuth {
    /**
     * The Factors param.
     */
    factors?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The MfaEnable param.
     */
    mfaEnable?: pulumi.Input<boolean>;
}
export interface AuthenticationProfileSingleSignOn {
    /**
     * The KerberosKeytab param. String length must not exceed 8192 characters.
     */
    kerberosKeytab?: pulumi.Input<string>;
    /**
     * The Realm param. String length must not exceed 127 characters.
     */
    realm?: pulumi.Input<string>;
}
export interface CertificateProfileCaCertificate {
    /**
     * The DefaultOcspUrl param.
     */
    defaultOcspUrl?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The OcspVerifyCert param.
     */
    ocspVerifyCert?: pulumi.Input<string>;
    /**
     * The TemplateName param.
     */
    templateName?: pulumi.Input<string>;
}
export interface CertificateProfileUsernameField {
    /**
     * The Subject param. String must be one of these: `"common-name"`.
     */
    subject?: pulumi.Input<string>;
    /**
     * The SubjectAlt param. String must be one of these: `"email"`.
     */
    subjectAlt?: pulumi.Input<string>;
}
export interface DecryptionProfileSslForwardProxy {
    /**
     * The AutoIncludeAltname param. Default: `false`.
     */
    autoIncludeAltname?: pulumi.Input<boolean>;
    /**
     * The BlockClientCert param. Default: `false`.
     */
    blockClientCert?: pulumi.Input<boolean>;
    /**
     * The BlockExpiredCertificate param. Default: `false`.
     */
    blockExpiredCertificate?: pulumi.Input<boolean>;
    /**
     * The BlockTimeoutCert param. Default: `false`.
     */
    blockTimeoutCert?: pulumi.Input<boolean>;
    /**
     * The BlockTls13DowngradeNoResource param. Default: `false`.
     */
    blockTls13DowngradeNoResource?: pulumi.Input<boolean>;
    /**
     * The BlockUnknownCert param. Default: `false`.
     */
    blockUnknownCert?: pulumi.Input<boolean>;
    /**
     * The BlockUnsupportedCipher param. Default: `false`.
     */
    blockUnsupportedCipher?: pulumi.Input<boolean>;
    /**
     * The BlockUnsupportedVersion param. Default: `false`.
     */
    blockUnsupportedVersion?: pulumi.Input<boolean>;
    /**
     * The BlockUntrustedIssuer param. Default: `false`.
     */
    blockUntrustedIssuer?: pulumi.Input<boolean>;
    /**
     * The RestrictCertExts param. Default: `false`.
     */
    restrictCertExts?: pulumi.Input<boolean>;
    /**
     * The StripAlpn param. Default: `false`.
     */
    stripAlpn?: pulumi.Input<boolean>;
}
export interface DecryptionProfileSslInboundProxy {
    /**
     * The BlockIfHsmUnavailable param. Default: `false`.
     */
    blockIfHsmUnavailable?: pulumi.Input<boolean>;
    /**
     * The BlockIfNoResource param. Default: `false`.
     */
    blockIfNoResource?: pulumi.Input<boolean>;
    /**
     * The BlockUnsupportedCipher param. Default: `false`.
     */
    blockUnsupportedCipher?: pulumi.Input<boolean>;
    /**
     * The BlockUnsupportedVersion param. Default: `false`.
     */
    blockUnsupportedVersion?: pulumi.Input<boolean>;
}
export interface DecryptionProfileSslNoProxy {
    /**
     * The BlockExpiredCertificate param. Default: `false`.
     */
    blockExpiredCertificate?: pulumi.Input<boolean>;
    /**
     * The BlockUntrustedIssuer param. Default: `false`.
     */
    blockUntrustedIssuer?: pulumi.Input<boolean>;
}
export interface DecryptionProfileSslProtocolSettings {
    /**
     * The AuthAlgoMd5 param. Default: `true`.
     */
    authAlgoMd5?: pulumi.Input<boolean>;
    /**
     * The AuthAlgoSha1 param. Default: `true`.
     */
    authAlgoSha1?: pulumi.Input<boolean>;
    /**
     * The AuthAlgoSha256 param. Default: `true`.
     */
    authAlgoSha256?: pulumi.Input<boolean>;
    /**
     * The AuthAlgoSha384 param. Default: `true`.
     */
    authAlgoSha384?: pulumi.Input<boolean>;
    /**
     * The EncAlgo3des param. Default: `true`.
     */
    encAlgo3des?: pulumi.Input<boolean>;
    /**
     * The EncAlgoAes128Cbc param. Default: `true`.
     */
    encAlgoAes128Cbc?: pulumi.Input<boolean>;
    /**
     * The EncAlgoAes128Gcm param. Default: `true`.
     */
    encAlgoAes128Gcm?: pulumi.Input<boolean>;
    /**
     * The EncAlgoAes256Cbc param. Default: `true`.
     */
    encAlgoAes256Cbc?: pulumi.Input<boolean>;
    /**
     * The EncAlgoAes256Gcm param. Default: `true`.
     */
    encAlgoAes256Gcm?: pulumi.Input<boolean>;
    /**
     * The EncAlgoChacha20Poly1305 param. Default: `true`.
     */
    encAlgoChacha20Poly1305?: pulumi.Input<boolean>;
    /**
     * The EncAlgoRc4 param. Default: `true`.
     */
    encAlgoRc4?: pulumi.Input<boolean>;
    /**
     * The KeyxchgAlgoDhe param. Default: `true`.
     */
    keyxchgAlgoDhe?: pulumi.Input<boolean>;
    /**
     * The KeyxchgAlgoEcdhe param. Default: `true`.
     */
    keyxchgAlgoEcdhe?: pulumi.Input<boolean>;
    /**
     * The KeyxchgAlgoRsa param. Default: `true`.
     */
    keyxchgAlgoRsa?: pulumi.Input<boolean>;
    /**
     * The MaxVersion param. String must be one of these: `"sslv3"`, `"tls1-0"`, `"tls1-1"`, `"tls1-2"`, `"tls1-3"`, `"max"`. Default: `"tls1-2"`.
     */
    maxVersion?: pulumi.Input<string>;
    /**
     * The MinVersion param. String must be one of these: `"sslv3"`, `"tls1-0"`, `"tls1-1"`, `"tls1-2"`, `"tls1-3"`. Default: `"tls1-0"`.
     */
    minVersion?: pulumi.Input<string>;
}
export interface DecryptionRuleType {
    /**
     * The SslForwardProxy param. Ensure that only one of the following is specified: `sslForwardProxy`, `sslInboundInspection`
     */
    sslForwardProxy?: pulumi.Input<boolean>;
    /**
     * add the certificate name for SSL inbound inspection. Ensure that only one of the following is specified: `sslForwardProxy`, `sslInboundInspection`
     */
    sslInboundInspection?: pulumi.Input<string>;
}
export interface DnsSecurityProfileBotnetDomains {
    /**
     * The DnsSecurityCategories param.
     */
    dnsSecurityCategories?: pulumi.Input<pulumi.Input<inputs.DnsSecurityProfileBotnetDomainsDnsSecurityCategory>[]>;
    /**
     * The Lists param.
     */
    lists?: pulumi.Input<pulumi.Input<inputs.DnsSecurityProfileBotnetDomainsList>[]>;
    /**
     * The Sinkhole param.
     */
    sinkhole?: pulumi.Input<inputs.DnsSecurityProfileBotnetDomainsSinkhole>;
    /**
     * The Whitelists param.
     */
    whitelists?: pulumi.Input<pulumi.Input<inputs.DnsSecurityProfileBotnetDomainsWhitelist>[]>;
}
export interface DnsSecurityProfileBotnetDomainsDnsSecurityCategory {
    /**
     * The Action param. String must be one of these: `"default"`, `"allow"`, `"block"`, `"sinkhole"`. Default: `"default"`.
     */
    action?: pulumi.Input<string>;
    /**
     * The LogLevel param. String must be one of these: `"default"`, `"none"`, `"low"`, `"informational"`, `"medium"`, `"high"`, `"critical"`. Default: `"default"`.
     */
    logLevel?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The PacketCapture param. String must be one of these: `"disable"`, `"single-packet"`, `"extended-capture"`.
     */
    packetCapture?: pulumi.Input<string>;
}
export interface DnsSecurityProfileBotnetDomainsList {
    /**
     * The Action param.
     */
    action?: pulumi.Input<inputs.DnsSecurityProfileBotnetDomainsListAction>;
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
    /**
     * The PacketCapture param. String must be one of these: `"disable"`, `"single-packet"`, `"extended-capture"`.
     */
    packetCapture?: pulumi.Input<string>;
}
export interface DnsSecurityProfileBotnetDomainsListAction {
    /**
     * The Alert param. Ensure that only one of the following is specified: `alert`, `allow`, `block`, `sinkhole`
     */
    alert?: pulumi.Input<boolean>;
    /**
     * The Allow param. Ensure that only one of the following is specified: `alert`, `allow`, `block`, `sinkhole`
     */
    allow?: pulumi.Input<boolean>;
    /**
     * The Block param. Ensure that only one of the following is specified: `alert`, `allow`, `block`, `sinkhole`
     */
    block?: pulumi.Input<boolean>;
    /**
     * The Sinkhole param. Ensure that only one of the following is specified: `alert`, `allow`, `block`, `sinkhole`
     */
    sinkhole?: pulumi.Input<boolean>;
}
export interface DnsSecurityProfileBotnetDomainsSinkhole {
    /**
     * The Ipv4Address param. String must be one of these: `"127.0.0.1"`, `"pan-sinkhole-default-ip"`.
     */
    ipv4Address?: pulumi.Input<string>;
    /**
     * The Ipv6Address param. String must be one of these: `"::1"`.
     */
    ipv6Address?: pulumi.Input<string>;
}
export interface DnsSecurityProfileBotnetDomainsWhitelist {
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
}
export interface ExternalDynamicListType {
    /**
     * The Domain param. Ensure that only one of the following is specified: `domain`, `imei`, `imsi`, `ip`, `predefinedIp`, `predefinedUrl`, `url`
     */
    domain?: pulumi.Input<inputs.ExternalDynamicListTypeDomain>;
    /**
     * The Imei param. Ensure that only one of the following is specified: `domain`, `imei`, `imsi`, `ip`, `predefinedIp`, `predefinedUrl`, `url`
     */
    imei?: pulumi.Input<inputs.ExternalDynamicListTypeImei>;
    /**
     * The Imsi param. Ensure that only one of the following is specified: `domain`, `imei`, `imsi`, `ip`, `predefinedIp`, `predefinedUrl`, `url`
     */
    imsi?: pulumi.Input<inputs.ExternalDynamicListTypeImsi>;
    /**
     * The Ip param. Ensure that only one of the following is specified: `domain`, `imei`, `imsi`, `ip`, `predefinedIp`, `predefinedUrl`, `url`
     */
    ip?: pulumi.Input<inputs.ExternalDynamicListTypeIp>;
    /**
     * The PredefinedIp param. Ensure that only one of the following is specified: `domain`, `imei`, `imsi`, `ip`, `predefinedIp`, `predefinedUrl`, `url`
     */
    predefinedIp?: pulumi.Input<inputs.ExternalDynamicListTypePredefinedIp>;
    /**
     * The PredefinedUrl param. Ensure that only one of the following is specified: `domain`, `imei`, `imsi`, `ip`, `predefinedIp`, `predefinedUrl`, `url`
     */
    predefinedUrl?: pulumi.Input<inputs.ExternalDynamicListTypePredefinedUrl>;
    /**
     * The Url param. Ensure that only one of the following is specified: `domain`, `imei`, `imsi`, `ip`, `predefinedIp`, `predefinedUrl`, `url`
     */
    url?: pulumi.Input<inputs.ExternalDynamicListTypeUrl>;
}
export interface ExternalDynamicListTypeDomain {
    /**
     * Profile for authenticating client certificates. Default: `"None"`.
     */
    certificateProfile?: pulumi.Input<string>;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The DomainAuth param.
     */
    domainAuth?: pulumi.Input<inputs.ExternalDynamicListTypeDomainDomainAuth>;
    /**
     * The ExceptionList param. Individual elements in this list are subject to additional validation. String length must not exceed 255 characters.
     */
    exceptionLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Enable/Disable expand domain. Default: `false`.
     */
    expandDomain?: pulumi.Input<boolean>;
    /**
     * The Recurring param.
     */
    recurring: pulumi.Input<inputs.ExternalDynamicListTypeDomainRecurring>;
    /**
     * The Url param. String length must not exceed 255 characters. Default: `"http://"`.
     */
    url?: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeDomainDomainAuth {
    /**
     * The Password param. String length must not exceed 255 characters.
     */
    password: pulumi.Input<string>;
    /**
     * The Username param. String length must be between 1 and 255 characters.
     */
    username: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeDomainRecurring {
    /**
     * The Daily param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    daily?: pulumi.Input<inputs.ExternalDynamicListTypeDomainRecurringDaily>;
    /**
     * The FiveMinute param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    fiveMinute?: pulumi.Input<boolean>;
    /**
     * The Hourly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    hourly?: pulumi.Input<boolean>;
    /**
     * The Monthly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    monthly?: pulumi.Input<inputs.ExternalDynamicListTypeDomainRecurringMonthly>;
    /**
     * The Weekly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    weekly?: pulumi.Input<inputs.ExternalDynamicListTypeDomainRecurringWeekly>;
}
export interface ExternalDynamicListTypeDomainRecurringDaily {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeDomainRecurringMonthly {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
    /**
     * The DayOfMonth param. Value must be between 1 and 31.
     */
    dayOfMonth: pulumi.Input<number>;
}
export interface ExternalDynamicListTypeDomainRecurringWeekly {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
    /**
     * The DayOfWeek param. String must be one of these: `"sunday"`, `"monday"`, `"tuesday"`, `"wednesday"`, `"thursday"`, `"friday"`, `"saturday"`.
     */
    dayOfWeek: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeImei {
    /**
     * Profile for authenticating client certificates. Default: `"None"`.
     */
    certificateProfile?: pulumi.Input<string>;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The ExceptionList param. Individual elements in this list are subject to additional validation. String length must not exceed 32 characters.
     */
    exceptionLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ImeiAuth param.
     */
    imeiAuth?: pulumi.Input<inputs.ExternalDynamicListTypeImeiImeiAuth>;
    /**
     * The Recurring param.
     */
    recurring: pulumi.Input<inputs.ExternalDynamicListTypeImeiRecurring>;
    /**
     * The Url param. String length must not exceed 255 characters. Default: `"http://"`.
     */
    url?: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeImeiImeiAuth {
    /**
     * The Password param. String length must not exceed 255 characters.
     */
    password: pulumi.Input<string>;
    /**
     * The Username param. String length must be between 1 and 255 characters.
     */
    username: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeImeiRecurring {
    /**
     * The Daily param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    daily?: pulumi.Input<inputs.ExternalDynamicListTypeImeiRecurringDaily>;
    /**
     * The FiveMinute param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    fiveMinute?: pulumi.Input<boolean>;
    /**
     * The Hourly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    hourly?: pulumi.Input<boolean>;
    /**
     * The Monthly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    monthly?: pulumi.Input<inputs.ExternalDynamicListTypeImeiRecurringMonthly>;
    /**
     * The Weekly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    weekly?: pulumi.Input<inputs.ExternalDynamicListTypeImeiRecurringWeekly>;
}
export interface ExternalDynamicListTypeImeiRecurringDaily {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeImeiRecurringMonthly {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
    /**
     * The DayOfMonth param. Value must be between 1 and 31.
     */
    dayOfMonth: pulumi.Input<number>;
}
export interface ExternalDynamicListTypeImeiRecurringWeekly {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
    /**
     * The DayOfWeek param. String must be one of these: `"sunday"`, `"monday"`, `"tuesday"`, `"wednesday"`, `"thursday"`, `"friday"`, `"saturday"`.
     */
    dayOfWeek: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeImsi {
    /**
     * Profile for authenticating client certificates. Default: `"None"`.
     */
    certificateProfile?: pulumi.Input<string>;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The ExceptionList param. Individual elements in this list are subject to additional validation. String length must not exceed 34 characters.
     */
    exceptionLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ImsiAuth param.
     */
    imsiAuth?: pulumi.Input<inputs.ExternalDynamicListTypeImsiImsiAuth>;
    /**
     * The Recurring param.
     */
    recurring: pulumi.Input<inputs.ExternalDynamicListTypeImsiRecurring>;
    /**
     * The Url param. String length must not exceed 255 characters. Default: `"http://"`.
     */
    url?: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeImsiImsiAuth {
    /**
     * The Password param. String length must not exceed 255 characters.
     */
    password: pulumi.Input<string>;
    /**
     * The Username param. String length must be between 1 and 255 characters.
     */
    username: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeImsiRecurring {
    /**
     * The Daily param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    daily?: pulumi.Input<inputs.ExternalDynamicListTypeImsiRecurringDaily>;
    /**
     * The FiveMinute param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    fiveMinute?: pulumi.Input<boolean>;
    /**
     * The Hourly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    hourly?: pulumi.Input<boolean>;
    /**
     * The Monthly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    monthly?: pulumi.Input<inputs.ExternalDynamicListTypeImsiRecurringMonthly>;
    /**
     * The Weekly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    weekly?: pulumi.Input<inputs.ExternalDynamicListTypeImsiRecurringWeekly>;
}
export interface ExternalDynamicListTypeImsiRecurringDaily {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeImsiRecurringMonthly {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
    /**
     * The DayOfMonth param. Value must be between 1 and 31.
     */
    dayOfMonth: pulumi.Input<number>;
}
export interface ExternalDynamicListTypeImsiRecurringWeekly {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
    /**
     * The DayOfWeek param. String must be one of these: `"sunday"`, `"monday"`, `"tuesday"`, `"wednesday"`, `"thursday"`, `"friday"`, `"saturday"`.
     */
    dayOfWeek: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeIp {
    /**
     * Profile for authenticating client certificates. Default: `"None"`.
     */
    certificateProfile?: pulumi.Input<string>;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The ExceptionList param. Individual elements in this list are subject to additional validation. String length must not exceed 255 characters.
     */
    exceptionLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The IpAuth param.
     */
    ipAuth?: pulumi.Input<inputs.ExternalDynamicListTypeIpIpAuth>;
    /**
     * The Recurring param.
     */
    recurring: pulumi.Input<inputs.ExternalDynamicListTypeIpRecurring>;
    /**
     * The Url param. String length must not exceed 255 characters. Default: `"http://"`.
     */
    url?: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeIpIpAuth {
    /**
     * The Password param. String length must not exceed 255 characters.
     */
    password: pulumi.Input<string>;
    /**
     * The Username param. String length must be between 1 and 255 characters.
     */
    username: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeIpRecurring {
    /**
     * The Daily param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    daily?: pulumi.Input<inputs.ExternalDynamicListTypeIpRecurringDaily>;
    /**
     * The FiveMinute param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    fiveMinute?: pulumi.Input<boolean>;
    /**
     * The Hourly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    hourly?: pulumi.Input<boolean>;
    /**
     * The Monthly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    monthly?: pulumi.Input<inputs.ExternalDynamicListTypeIpRecurringMonthly>;
    /**
     * The Weekly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    weekly?: pulumi.Input<inputs.ExternalDynamicListTypeIpRecurringWeekly>;
}
export interface ExternalDynamicListTypeIpRecurringDaily {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeIpRecurringMonthly {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
    /**
     * The DayOfMonth param. Value must be between 1 and 31.
     */
    dayOfMonth: pulumi.Input<number>;
}
export interface ExternalDynamicListTypeIpRecurringWeekly {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
    /**
     * The DayOfWeek param. String must be one of these: `"sunday"`, `"monday"`, `"tuesday"`, `"wednesday"`, `"thursday"`, `"friday"`, `"saturday"`.
     */
    dayOfWeek: pulumi.Input<string>;
}
export interface ExternalDynamicListTypePredefinedIp {
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The ExceptionList param. Individual elements in this list are subject to additional validation. String length must not exceed 255 characters.
     */
    exceptionLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Url param.
     */
    url: pulumi.Input<string>;
}
export interface ExternalDynamicListTypePredefinedUrl {
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The ExceptionList param. Individual elements in this list are subject to additional validation. String length must not exceed 255 characters.
     */
    exceptionLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Url param.
     */
    url: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeUrl {
    /**
     * Profile for authenticating client certificates. Default: `"None"`.
     */
    certificateProfile?: pulumi.Input<string>;
    /**
     * The Description param. String length must not exceed 255 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The ExceptionList param. Individual elements in this list are subject to additional validation. String length must not exceed 255 characters.
     */
    exceptionLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Recurring param.
     */
    recurring: pulumi.Input<inputs.ExternalDynamicListTypeUrlRecurring>;
    /**
     * The Url param. String length must not exceed 255 characters. Default: `"http://"`.
     */
    url?: pulumi.Input<string>;
    /**
     * The UrlAuth param.
     */
    urlAuth?: pulumi.Input<inputs.ExternalDynamicListTypeUrlUrlAuth>;
}
export interface ExternalDynamicListTypeUrlRecurring {
    /**
     * The Daily param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    daily?: pulumi.Input<inputs.ExternalDynamicListTypeUrlRecurringDaily>;
    /**
     * The FiveMinute param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    fiveMinute?: pulumi.Input<boolean>;
    /**
     * The Hourly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    hourly?: pulumi.Input<boolean>;
    /**
     * The Monthly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    monthly?: pulumi.Input<inputs.ExternalDynamicListTypeUrlRecurringMonthly>;
    /**
     * The Weekly param. Ensure that only one of the following is specified: `daily`, `fiveMinute`, `hourly`, `monthly`, `weekly`
     */
    weekly?: pulumi.Input<inputs.ExternalDynamicListTypeUrlRecurringWeekly>;
}
export interface ExternalDynamicListTypeUrlRecurringDaily {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeUrlRecurringMonthly {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
    /**
     * The DayOfMonth param. Value must be between 1 and 31.
     */
    dayOfMonth: pulumi.Input<number>;
}
export interface ExternalDynamicListTypeUrlRecurringWeekly {
    /**
     * Time specification hh (e.g. 20). String length must be between 2 and 2 characters. String validation regex: `([01][0-9]|[2][0-3])`. Default: `"00"`.
     */
    at?: pulumi.Input<string>;
    /**
     * The DayOfWeek param. String must be one of these: `"sunday"`, `"monday"`, `"tuesday"`, `"wednesday"`, `"thursday"`, `"friday"`, `"saturday"`.
     */
    dayOfWeek: pulumi.Input<string>;
}
export interface ExternalDynamicListTypeUrlUrlAuth {
    /**
     * The Password param. String length must not exceed 255 characters.
     */
    password: pulumi.Input<string>;
    /**
     * The Username param. String length must be between 1 and 255 characters.
     */
    username: pulumi.Input<string>;
}
export interface FileBlockingProfileRule {
    /**
     * The Action param. String must be one of these: `"alert"`, `"block"`, `"continue"`. Default: `"alert"`.
     */
    action?: pulumi.Input<string>;
    /**
     * The Applications param. List must contain at least 1 elements.
     */
    applications: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Direction param. String must be one of these: `"download"`, `"upload"`, `"both"`. Default: `"both"`.
     */
    direction?: pulumi.Input<string>;
    /**
     * The FileTypes param. List must contain at least 1 elements.
     */
    fileTypes: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
}
export interface HipObjectAntiMalware {
    /**
     * The Criteria param.
     */
    criteria?: pulumi.Input<inputs.HipObjectAntiMalwareCriteria>;
    /**
     * The ExcludeVendor param. Default: `false`.
     */
    excludeVendor?: pulumi.Input<boolean>;
    /**
     * Vendor name.
     */
    vendors?: pulumi.Input<pulumi.Input<inputs.HipObjectAntiMalwareVendor>[]>;
}
export interface HipObjectAntiMalwareCriteria {
    /**
     * Is Installed. Default: `true`.
     */
    isInstalled?: pulumi.Input<boolean>;
    /**
     * The LastScanTime param.
     */
    lastScanTime?: pulumi.Input<inputs.HipObjectAntiMalwareCriteriaLastScanTime>;
    /**
     * The ProductVersion param.
     */
    productVersion?: pulumi.Input<inputs.HipObjectAntiMalwareCriteriaProductVersion>;
    /**
     * real time protection. String must be one of these: `"no"`, `"yes"`, `"not-available"`.
     */
    realTimeProtection?: pulumi.Input<string>;
    /**
     * The VirdefVersion param.
     */
    virdefVersion?: pulumi.Input<inputs.HipObjectAntiMalwareCriteriaVirdefVersion>;
}
export interface HipObjectAntiMalwareCriteriaLastScanTime {
    /**
     * The NotAvailable param. Ensure that only one of the following is specified: `notAvailable`, `notWithin`, `within`
     */
    notAvailable?: pulumi.Input<boolean>;
    /**
     * The NotWithin param. Ensure that only one of the following is specified: `notAvailable`, `notWithin`, `within`
     */
    notWithin?: pulumi.Input<inputs.HipObjectAntiMalwareCriteriaLastScanTimeNotWithin>;
    /**
     * The Within param. Ensure that only one of the following is specified: `notAvailable`, `notWithin`, `within`
     */
    within?: pulumi.Input<inputs.HipObjectAntiMalwareCriteriaLastScanTimeWithin>;
}
export interface HipObjectAntiMalwareCriteriaLastScanTimeNotWithin {
    /**
     * specify time in days. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `hours`
     */
    days?: pulumi.Input<number>;
    /**
     * specify time in hours. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `hours`
     */
    hours?: pulumi.Input<number>;
}
export interface HipObjectAntiMalwareCriteriaLastScanTimeWithin {
    /**
     * specify time in days. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `hours`
     */
    days?: pulumi.Input<number>;
    /**
     * specify time in hours. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `hours`
     */
    hours?: pulumi.Input<number>;
}
export interface HipObjectAntiMalwareCriteriaProductVersion {
    /**
     * The Contains param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`, `notWithin`, `within`
     */
    contains?: pulumi.Input<string>;
    /**
     * The GreaterEqual param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`, `notWithin`, `within`
     */
    greaterEqual?: pulumi.Input<string>;
    /**
     * The GreaterThan param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`, `notWithin`, `within`
     */
    greaterThan?: pulumi.Input<string>;
    /**
     * The Is param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`, `notWithin`, `within`
     */
    is?: pulumi.Input<string>;
    /**
     * The IsNot param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`, `notWithin`, `within`
     */
    isNot?: pulumi.Input<string>;
    /**
     * The LessEqual param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`, `notWithin`, `within`
     */
    lessEqual?: pulumi.Input<string>;
    /**
     * The LessThan param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`, `notWithin`, `within`
     */
    lessThan?: pulumi.Input<string>;
    /**
     * The NotWithin param. Ensure that only one of the following is specified: `contains`, `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`, `notWithin`, `within`
     */
    notWithin?: pulumi.Input<inputs.HipObjectAntiMalwareCriteriaProductVersionNotWithin>;
    /**
     * The Within param. Ensure that only one of the following is specified: `contains`, `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`, `notWithin`, `within`
     */
    within?: pulumi.Input<inputs.HipObjectAntiMalwareCriteriaProductVersionWithin>;
}
export interface HipObjectAntiMalwareCriteriaProductVersionNotWithin {
    /**
     * versions range. Value must be between 1 and 65535. Default: `1`.
     */
    versions?: pulumi.Input<number>;
}
export interface HipObjectAntiMalwareCriteriaProductVersionWithin {
    /**
     * versions range. Value must be between 1 and 65535. Default: `1`.
     */
    versions?: pulumi.Input<number>;
}
export interface HipObjectAntiMalwareCriteriaVirdefVersion {
    /**
     * The NotWithin param. Ensure that only one of the following is specified: `notWithin`, `within`
     */
    notWithin?: pulumi.Input<inputs.HipObjectAntiMalwareCriteriaVirdefVersionNotWithin>;
    /**
     * The Within param. Ensure that only one of the following is specified: `notWithin`, `within`
     */
    within?: pulumi.Input<inputs.HipObjectAntiMalwareCriteriaVirdefVersionWithin>;
}
export interface HipObjectAntiMalwareCriteriaVirdefVersionNotWithin {
    /**
     * specify time in days. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `versions`
     */
    days?: pulumi.Input<number>;
    /**
     * specify versions range. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `versions`
     */
    versions?: pulumi.Input<number>;
}
export interface HipObjectAntiMalwareCriteriaVirdefVersionWithin {
    /**
     * specify time in days. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `versions`
     */
    days?: pulumi.Input<number>;
    /**
     * specify versions range. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `versions`
     */
    versions?: pulumi.Input<number>;
}
export interface HipObjectAntiMalwareVendor {
    /**
     * The Name param. String length must not exceed 103 characters.
     */
    name: pulumi.Input<string>;
    /**
     * The Products param. Individual elements in this list are subject to additional validation. String length must not exceed 1023 characters. String validation regex: `.*`.
     */
    products?: pulumi.Input<pulumi.Input<string>[]>;
}
export interface HipObjectCertificate {
    /**
     * The Criteria param.
     */
    criteria?: pulumi.Input<inputs.HipObjectCertificateCriteria>;
}
export interface HipObjectCertificateCriteria {
    /**
     * The CertificateAttributes param.
     */
    certificateAttributes?: pulumi.Input<pulumi.Input<inputs.HipObjectCertificateCriteriaCertificateAttribute>[]>;
    /**
     * Profile for authenticating client certificates.
     */
    certificateProfile?: pulumi.Input<string>;
}
export interface HipObjectCertificateCriteriaCertificateAttribute {
    /**
     * Attribute Name.
     */
    name: pulumi.Input<string>;
    /**
     * Key value. String length must not exceed 1024 characters. String validation regex: `.*`.
     */
    value?: pulumi.Input<string>;
}
export interface HipObjectCustomChecks {
    /**
     * The Criteria param.
     */
    criteria: pulumi.Input<inputs.HipObjectCustomChecksCriteria>;
}
export interface HipObjectCustomChecksCriteria {
    /**
     * The Plist param.
     */
    plists?: pulumi.Input<pulumi.Input<inputs.HipObjectCustomChecksCriteriaPlist>[]>;
    /**
     * The ProcessList param.
     */
    processLists?: pulumi.Input<pulumi.Input<inputs.HipObjectCustomChecksCriteriaProcessList>[]>;
    /**
     * The RegistryKeys param.
     */
    registryKeys?: pulumi.Input<pulumi.Input<inputs.HipObjectCustomChecksCriteriaRegistryKey>[]>;
}
export interface HipObjectCustomChecksCriteriaPlist {
    /**
     * The Keys param.
     */
    keys?: pulumi.Input<pulumi.Input<inputs.HipObjectCustomChecksCriteriaPlistKey>[]>;
    /**
     * Preference list. String length must not exceed 1023 characters.
     */
    name: pulumi.Input<string>;
    /**
     * Plist does not exist. Default: `false`.
     */
    negate?: pulumi.Input<boolean>;
}
export interface HipObjectCustomChecksCriteriaPlistKey {
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name: pulumi.Input<string>;
    /**
     * Value does not exist or match specified value data. Default: `false`.
     */
    negate?: pulumi.Input<boolean>;
    /**
     * Key value. String length must not exceed 1024 characters. String validation regex: `.*`.
     */
    value?: pulumi.Input<string>;
}
export interface HipObjectCustomChecksCriteriaProcessList {
    /**
     * Process Name. String length must not exceed 1023 characters.
     */
    name: pulumi.Input<string>;
    /**
     * The Running param. Default: `true`.
     */
    running?: pulumi.Input<boolean>;
}
export interface HipObjectCustomChecksCriteriaRegistryKey {
    /**
     * Registry key default value data. String length must not exceed 1024 characters. String validation regex: `.*`.
     */
    defaultValueData?: pulumi.Input<string>;
    /**
     * Registry key. String length must not exceed 1023 characters.
     */
    name: pulumi.Input<string>;
    /**
     * Key does not exist or match specified value data. Default: `false`.
     */
    negate?: pulumi.Input<boolean>;
    /**
     * The RegistryValues param.
     */
    registryValues?: pulumi.Input<pulumi.Input<inputs.HipObjectCustomChecksCriteriaRegistryKeyRegistryValue>[]>;
}
export interface HipObjectCustomChecksCriteriaRegistryKeyRegistryValue {
    /**
     * Registry value name. String length must not exceed 1023 characters.
     */
    name: pulumi.Input<string>;
    /**
     * Value does not exist or match specified value data. Default: `false`.
     */
    negate?: pulumi.Input<boolean>;
    /**
     * Registry value data. String length must not exceed 1024 characters. String validation regex: `.*`.
     */
    valueData?: pulumi.Input<string>;
}
export interface HipObjectDataLossPrevention {
    /**
     * The Criteria param.
     */
    criteria?: pulumi.Input<inputs.HipObjectDataLossPreventionCriteria>;
    /**
     * The ExcludeVendor param. Default: `false`.
     */
    excludeVendor?: pulumi.Input<boolean>;
    /**
     * Vendor name.
     */
    vendors?: pulumi.Input<pulumi.Input<inputs.HipObjectDataLossPreventionVendor>[]>;
}
export interface HipObjectDataLossPreventionCriteria {
    /**
     * is enabled. String must be one of these: `"no"`, `"yes"`, `"not-available"`.
     */
    isEnabled?: pulumi.Input<string>;
    /**
     * Is Installed. Default: `true`.
     */
    isInstalled?: pulumi.Input<boolean>;
}
export interface HipObjectDataLossPreventionVendor {
    /**
     * The Name param. String length must not exceed 103 characters.
     */
    name: pulumi.Input<string>;
    /**
     * Product name. Individual elements in this list are subject to additional validation. String length must not exceed 1023 characters. String validation regex: `.*`.
     */
    products?: pulumi.Input<pulumi.Input<string>[]>;
}
export interface HipObjectDiskBackup {
    /**
     * The Criteria param.
     */
    criteria?: pulumi.Input<inputs.HipObjectDiskBackupCriteria>;
    /**
     * The ExcludeVendor param. Default: `false`.
     */
    excludeVendor?: pulumi.Input<boolean>;
    /**
     * Vendor name.
     */
    vendors?: pulumi.Input<pulumi.Input<inputs.HipObjectDiskBackupVendor>[]>;
}
export interface HipObjectDiskBackupCriteria {
    /**
     * Is Installed. Default: `true`.
     */
    isInstalled?: pulumi.Input<boolean>;
    /**
     * The LastBackupTime param.
     */
    lastBackupTime?: pulumi.Input<inputs.HipObjectDiskBackupCriteriaLastBackupTime>;
}
export interface HipObjectDiskBackupCriteriaLastBackupTime {
    /**
     * The NotAvailable param. Ensure that only one of the following is specified: `notAvailable`, `notWithin`, `within`
     */
    notAvailable?: pulumi.Input<boolean>;
    /**
     * The NotWithin param. Ensure that only one of the following is specified: `notAvailable`, `notWithin`, `within`
     */
    notWithin?: pulumi.Input<inputs.HipObjectDiskBackupCriteriaLastBackupTimeNotWithin>;
    /**
     * The Within param. Ensure that only one of the following is specified: `notAvailable`, `notWithin`, `within`
     */
    within?: pulumi.Input<inputs.HipObjectDiskBackupCriteriaLastBackupTimeWithin>;
}
export interface HipObjectDiskBackupCriteriaLastBackupTimeNotWithin {
    /**
     * specify time in days. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `hours`
     */
    days?: pulumi.Input<number>;
    /**
     * specify time in hours. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `hours`
     */
    hours?: pulumi.Input<number>;
}
export interface HipObjectDiskBackupCriteriaLastBackupTimeWithin {
    /**
     * specify time in days. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `hours`
     */
    days?: pulumi.Input<number>;
    /**
     * specify time in hours. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `hours`
     */
    hours?: pulumi.Input<number>;
}
export interface HipObjectDiskBackupVendor {
    /**
     * The Name param. String length must not exceed 103 characters.
     */
    name: pulumi.Input<string>;
    /**
     * The Products param. Individual elements in this list are subject to additional validation. String length must not exceed 1023 characters. String validation regex: `.*`.
     */
    products?: pulumi.Input<pulumi.Input<string>[]>;
}
export interface HipObjectDiskEncryption {
    /**
     * Encryption locations.
     */
    criteria?: pulumi.Input<inputs.HipObjectDiskEncryptionCriteria>;
    /**
     * The ExcludeVendor param. Default: `false`.
     */
    excludeVendor?: pulumi.Input<boolean>;
    /**
     * Vendor name.
     */
    vendors?: pulumi.Input<pulumi.Input<inputs.HipObjectDiskEncryptionVendor>[]>;
}
export interface HipObjectDiskEncryptionCriteria {
    /**
     * The EncryptedLocations param.
     */
    encryptedLocations?: pulumi.Input<pulumi.Input<inputs.HipObjectDiskEncryptionCriteriaEncryptedLocation>[]>;
    /**
     * Is Installed. Default: `true`.
     */
    isInstalled?: pulumi.Input<boolean>;
}
export interface HipObjectDiskEncryptionCriteriaEncryptedLocation {
    /**
     * The EncryptionState param.
     */
    encryptionState?: pulumi.Input<inputs.HipObjectDiskEncryptionCriteriaEncryptedLocationEncryptionState>;
    /**
     * Encryption location. String length must not exceed 1023 characters.
     */
    name: pulumi.Input<string>;
}
export interface HipObjectDiskEncryptionCriteriaEncryptedLocationEncryptionState {
    /**
     * The Is param. String must be one of these: `"encrypted"`, `"unencrypted"`, `"partial"`, `"unknown"`. Ensure that only one of the following is specified: `is`, `isNot`
     */
    is?: pulumi.Input<string>;
    /**
     * The IsNot param. String must be one of these: `"encrypted"`, `"unencrypted"`, `"partial"`, `"unknown"`. Ensure that only one of the following is specified: `is`, `isNot`
     */
    isNot?: pulumi.Input<string>;
}
export interface HipObjectDiskEncryptionVendor {
    /**
     * The Name param. String length must not exceed 103 characters.
     */
    name: pulumi.Input<string>;
    /**
     * The Products param. Individual elements in this list are subject to additional validation. String length must not exceed 1023 characters. String validation regex: `.*`.
     */
    products?: pulumi.Input<pulumi.Input<string>[]>;
}
export interface HipObjectFirewall {
    /**
     * The Criteria param.
     */
    criteria?: pulumi.Input<inputs.HipObjectFirewallCriteria>;
    /**
     * The ExcludeVendor param. Default: `false`.
     */
    excludeVendor?: pulumi.Input<boolean>;
    /**
     * Vendor name.
     */
    vendors?: pulumi.Input<pulumi.Input<inputs.HipObjectFirewallVendor>[]>;
}
export interface HipObjectFirewallCriteria {
    /**
     * is enabled. String must be one of these: `"no"`, `"yes"`, `"not-available"`.
     */
    isEnabled?: pulumi.Input<string>;
    /**
     * Is Installed. Default: `true`.
     */
    isInstalled?: pulumi.Input<boolean>;
}
export interface HipObjectFirewallVendor {
    /**
     * The Name param. String length must not exceed 103 characters.
     */
    name: pulumi.Input<string>;
    /**
     * The Products param. Individual elements in this list are subject to additional validation. String length must not exceed 1023 characters. String validation regex: `.*`.
     */
    products?: pulumi.Input<pulumi.Input<string>[]>;
}
export interface HipObjectHostInfo {
    /**
     * The Criteria param.
     */
    criteria: pulumi.Input<inputs.HipObjectHostInfoCriteria>;
}
export interface HipObjectHostInfoCriteria {
    /**
     * The ClientVersion param.
     */
    clientVersion?: pulumi.Input<inputs.HipObjectHostInfoCriteriaClientVersion>;
    /**
     * The Domain param.
     */
    domain?: pulumi.Input<inputs.HipObjectHostInfoCriteriaDomain>;
    /**
     * The HostId param.
     */
    hostId?: pulumi.Input<inputs.HipObjectHostInfoCriteriaHostId>;
    /**
     * The HostName param.
     */
    hostName?: pulumi.Input<inputs.HipObjectHostInfoCriteriaHostName>;
    /**
     * If device is managed.
     */
    managed?: pulumi.Input<boolean>;
    /**
     * The Os param.
     */
    os?: pulumi.Input<inputs.HipObjectHostInfoCriteriaOs>;
    /**
     * The SerialNumber param.
     */
    serialNumber?: pulumi.Input<inputs.HipObjectHostInfoCriteriaSerialNumber>;
}
export interface HipObjectHostInfoCriteriaClientVersion {
    /**
     * The Contains param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    contains?: pulumi.Input<string>;
    /**
     * The Is param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    is?: pulumi.Input<string>;
    /**
     * The IsNot param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    isNot?: pulumi.Input<string>;
}
export interface HipObjectHostInfoCriteriaDomain {
    /**
     * The Contains param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    contains?: pulumi.Input<string>;
    /**
     * The Is param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    is?: pulumi.Input<string>;
    /**
     * The IsNot param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    isNot?: pulumi.Input<string>;
}
export interface HipObjectHostInfoCriteriaHostId {
    /**
     * The Contains param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    contains?: pulumi.Input<string>;
    /**
     * The Is param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    is?: pulumi.Input<string>;
    /**
     * The IsNot param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    isNot?: pulumi.Input<string>;
}
export interface HipObjectHostInfoCriteriaHostName {
    /**
     * The Contains param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    contains?: pulumi.Input<string>;
    /**
     * The Is param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    is?: pulumi.Input<string>;
    /**
     * The IsNot param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    isNot?: pulumi.Input<string>;
}
export interface HipObjectHostInfoCriteriaOs {
    /**
     * The Contains param. Ensure that only one of the following is specified: `contains`
     */
    contains?: pulumi.Input<inputs.HipObjectHostInfoCriteriaOsContains>;
}
export interface HipObjectHostInfoCriteriaOsContains {
    /**
     * Apple vendor. String length must not exceed 255 characters. Ensure that only one of the following is specified: `Apple`, `Google`, `Linux`, `Microsoft`, `Other`
     */
    apple?: pulumi.Input<string>;
    /**
     * Google vendor. String length must not exceed 255 characters. Ensure that only one of the following is specified: `Apple`, `Google`, `Linux`, `Microsoft`, `Other`
     */
    google?: pulumi.Input<string>;
    /**
     * Linux vendor. String length must not exceed 255 characters. Ensure that only one of the following is specified: `Apple`, `Google`, `Linux`, `Microsoft`, `Other`
     */
    linux?: pulumi.Input<string>;
    /**
     * Microsoft vendor. String length must not exceed 255 characters. Ensure that only one of the following is specified: `Apple`, `Google`, `Linux`, `Microsoft`, `Other`
     */
    microsoft?: pulumi.Input<string>;
    /**
     * Other vendor. String length must not exceed 255 characters. Ensure that only one of the following is specified: `Apple`, `Google`, `Linux`, `Microsoft`, `Other`
     */
    other?: pulumi.Input<string>;
}
export interface HipObjectHostInfoCriteriaSerialNumber {
    /**
     * The Contains param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    contains?: pulumi.Input<string>;
    /**
     * The Is param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    is?: pulumi.Input<string>;
    /**
     * The IsNot param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    isNot?: pulumi.Input<string>;
}
export interface HipObjectMobileDevice {
    /**
     * The Criteria param.
     */
    criteria?: pulumi.Input<inputs.HipObjectMobileDeviceCriteria>;
}
export interface HipObjectMobileDeviceCriteria {
    /**
     * The Applications param.
     */
    applications?: pulumi.Input<inputs.HipObjectMobileDeviceCriteriaApplications>;
    /**
     * If device's disk is encrypted.
     */
    diskEncrypted?: pulumi.Input<boolean>;
    /**
     * The Imei param.
     */
    imei?: pulumi.Input<inputs.HipObjectMobileDeviceCriteriaImei>;
    /**
     * If device is by rooted/jailbroken.
     */
    jailbroken?: pulumi.Input<boolean>;
    /**
     * The LastCheckinTime param.
     */
    lastCheckinTime?: pulumi.Input<inputs.HipObjectMobileDeviceCriteriaLastCheckinTime>;
    /**
     * The Model param.
     */
    model?: pulumi.Input<inputs.HipObjectMobileDeviceCriteriaModel>;
    /**
     * If device's passcode is present.
     */
    passcodeSet?: pulumi.Input<boolean>;
    /**
     * The PhoneNumber param.
     */
    phoneNumber?: pulumi.Input<inputs.HipObjectMobileDeviceCriteriaPhoneNumber>;
    /**
     * The Tag param.
     */
    tag?: pulumi.Input<inputs.HipObjectMobileDeviceCriteriaTag>;
}
export interface HipObjectMobileDeviceCriteriaApplications {
    /**
     * The HasMalware param.
     */
    hasMalware?: pulumi.Input<inputs.HipObjectMobileDeviceCriteriaApplicationsHasMalware>;
    /**
     * Has apps that are not managed.
     */
    hasUnmanagedApp?: pulumi.Input<boolean>;
    /**
     * The Includes param.
     */
    includes?: pulumi.Input<pulumi.Input<inputs.HipObjectMobileDeviceCriteriaApplicationsInclude>[]>;
}
export interface HipObjectMobileDeviceCriteriaApplicationsHasMalware {
    /**
     * The No param. Ensure that only one of the following is specified: `no`, `yes`
     */
    no?: pulumi.Input<boolean>;
    /**
     * The Yes param. Ensure that only one of the following is specified: `no`, `yes`
     */
    yes?: pulumi.Input<inputs.HipObjectMobileDeviceCriteriaApplicationsHasMalwareYes>;
}
export interface HipObjectMobileDeviceCriteriaApplicationsHasMalwareYes {
    /**
     * The Excludes param.
     */
    excludes?: pulumi.Input<pulumi.Input<inputs.HipObjectMobileDeviceCriteriaApplicationsHasMalwareYesExclude>[]>;
}
export interface HipObjectMobileDeviceCriteriaApplicationsHasMalwareYesExclude {
    /**
     * application hash. String length must not exceed 1024 characters. String validation regex: `.*`.
     */
    hash?: pulumi.Input<string>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name: pulumi.Input<string>;
    /**
     * application package name. String length must not exceed 1024 characters. String validation regex: `.*`.
     */
    package?: pulumi.Input<string>;
}
export interface HipObjectMobileDeviceCriteriaApplicationsInclude {
    /**
     * application hash. String length must not exceed 1024 characters. String validation regex: `.*`.
     */
    hash?: pulumi.Input<string>;
    /**
     * The Name param. String length must not exceed 31 characters.
     */
    name: pulumi.Input<string>;
    /**
     * application package name. String length must not exceed 1024 characters. String validation regex: `.*`.
     */
    package?: pulumi.Input<string>;
}
export interface HipObjectMobileDeviceCriteriaImei {
    /**
     * The Contains param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    contains?: pulumi.Input<string>;
    /**
     * The Is param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    is?: pulumi.Input<string>;
    /**
     * The IsNot param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    isNot?: pulumi.Input<string>;
}
export interface HipObjectMobileDeviceCriteriaLastCheckinTime {
    /**
     * The NotWithin param. Ensure that only one of the following is specified: `notWithin`, `within`
     */
    notWithin?: pulumi.Input<inputs.HipObjectMobileDeviceCriteriaLastCheckinTimeNotWithin>;
    /**
     * The Within param. Ensure that only one of the following is specified: `notWithin`, `within`
     */
    within?: pulumi.Input<inputs.HipObjectMobileDeviceCriteriaLastCheckinTimeWithin>;
}
export interface HipObjectMobileDeviceCriteriaLastCheckinTimeNotWithin {
    /**
     * specify time in days. Value must be between 1 and 365. Default: `30`.
     */
    days?: pulumi.Input<number>;
}
export interface HipObjectMobileDeviceCriteriaLastCheckinTimeWithin {
    /**
     * specify time in days. Value must be between 1 and 365. Default: `30`.
     */
    days?: pulumi.Input<number>;
}
export interface HipObjectMobileDeviceCriteriaModel {
    /**
     * The Contains param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    contains?: pulumi.Input<string>;
    /**
     * The Is param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    is?: pulumi.Input<string>;
    /**
     * The IsNot param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    isNot?: pulumi.Input<string>;
}
export interface HipObjectMobileDeviceCriteriaPhoneNumber {
    /**
     * The Contains param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    contains?: pulumi.Input<string>;
    /**
     * The Is param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    is?: pulumi.Input<string>;
    /**
     * The IsNot param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    isNot?: pulumi.Input<string>;
}
export interface HipObjectMobileDeviceCriteriaTag {
    /**
     * The Contains param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    contains?: pulumi.Input<string>;
    /**
     * The Is param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    is?: pulumi.Input<string>;
    /**
     * The IsNot param. String length must not exceed 255 characters. Ensure that only one of the following is specified: `contains`, `is`, `isNot`
     */
    isNot?: pulumi.Input<string>;
}
export interface HipObjectNetworkInfo {
    /**
     * The Criteria param.
     */
    criteria?: pulumi.Input<inputs.HipObjectNetworkInfoCriteria>;
}
export interface HipObjectNetworkInfoCriteria {
    /**
     * The Network param.
     */
    network?: pulumi.Input<inputs.HipObjectNetworkInfoCriteriaNetwork>;
}
export interface HipObjectNetworkInfoCriteriaNetwork {
    /**
     * The Is param. Ensure that only one of the following is specified: `is`, `isNot`
     */
    is?: pulumi.Input<inputs.HipObjectNetworkInfoCriteriaNetworkIs>;
    /**
     * The IsNot param. Ensure that only one of the following is specified: `is`, `isNot`
     */
    isNot?: pulumi.Input<inputs.HipObjectNetworkInfoCriteriaNetworkIsNot>;
}
export interface HipObjectNetworkInfoCriteriaNetworkIs {
    /**
     * The Mobile param. Ensure that only one of the following is specified: `mobile`, `unknown`, `wifi`
     */
    mobile?: pulumi.Input<inputs.HipObjectNetworkInfoCriteriaNetworkIsMobile>;
    /**
     * The Unknown param. Ensure that only one of the following is specified: `mobile`, `unknown`, `wifi`
     */
    unknown?: pulumi.Input<boolean>;
    /**
     * The Wifi param. Ensure that only one of the following is specified: `mobile`, `unknown`, `wifi`
     */
    wifi?: pulumi.Input<inputs.HipObjectNetworkInfoCriteriaNetworkIsWifi>;
}
export interface HipObjectNetworkInfoCriteriaNetworkIsMobile {
    /**
     * The Carrier param. String length must not exceed 1023 characters. String validation regex: `.*`.
     */
    carrier?: pulumi.Input<string>;
}
export interface HipObjectNetworkInfoCriteriaNetworkIsNot {
    /**
     * The Ethernet param. Ensure that only one of the following is specified: `ethernet`, `mobile`, `unknown`, `wifi`
     */
    ethernet?: pulumi.Input<boolean>;
    /**
     * The Mobile param. Ensure that only one of the following is specified: `ethernet`, `mobile`, `unknown`, `wifi`
     */
    mobile?: pulumi.Input<inputs.HipObjectNetworkInfoCriteriaNetworkIsNotMobile>;
    /**
     * The Unknown param. Ensure that only one of the following is specified: `ethernet`, `mobile`, `unknown`, `wifi`
     */
    unknown?: pulumi.Input<boolean>;
    /**
     * The Wifi param. Ensure that only one of the following is specified: `ethernet`, `mobile`, `unknown`, `wifi`
     */
    wifi?: pulumi.Input<inputs.HipObjectNetworkInfoCriteriaNetworkIsNotWifi>;
}
export interface HipObjectNetworkInfoCriteriaNetworkIsNotMobile {
    /**
     * The Carrier param. String length must not exceed 1023 characters. String validation regex: `.*`.
     */
    carrier?: pulumi.Input<string>;
}
export interface HipObjectNetworkInfoCriteriaNetworkIsNotWifi {
    /**
     * SSID. String length must not exceed 1023 characters. String validation regex: `.*`.
     */
    ssid?: pulumi.Input<string>;
}
export interface HipObjectNetworkInfoCriteriaNetworkIsWifi {
    /**
     * SSID. String length must not exceed 1023 characters. String validation regex: `.*`.
     */
    ssid?: pulumi.Input<string>;
}
export interface HipObjectPatchManagement {
    /**
     * The Criteria param.
     */
    criteria?: pulumi.Input<inputs.HipObjectPatchManagementCriteria>;
    /**
     * The ExcludeVendor param. Default: `false`.
     */
    excludeVendor?: pulumi.Input<boolean>;
    /**
     * Vendor name.
     */
    vendors?: pulumi.Input<pulumi.Input<inputs.HipObjectPatchManagementVendor>[]>;
}
export interface HipObjectPatchManagementCriteria {
    /**
     * is enabled. String must be one of these: `"no"`, `"yes"`, `"not-available"`.
     */
    isEnabled?: pulumi.Input<string>;
    /**
     * Is Installed. Default: `true`.
     */
    isInstalled?: pulumi.Input<boolean>;
    /**
     * The MissingPatches param.
     */
    missingPatches?: pulumi.Input<inputs.HipObjectPatchManagementCriteriaMissingPatches>;
}
export interface HipObjectPatchManagementCriteriaMissingPatches {
    /**
     * The Check param. String must be one of these: `"has-any"`, `"has-none"`, `"has-all"`. Default: `"has-any"`.
     */
    check?: pulumi.Input<string>;
    /**
     * The Patches param. Individual elements in this list are subject to additional validation. String length must not exceed 1023 characters. String validation regex: `.*`.
     */
    patches?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Severity param.
     */
    severity?: pulumi.Input<inputs.HipObjectPatchManagementCriteriaMissingPatchesSeverity>;
}
export interface HipObjectPatchManagementCriteriaMissingPatchesSeverity {
    /**
     * The GreaterEqual param. Value must be between 0 and 100000. Ensure that only one of the following is specified: `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`
     */
    greaterEqual?: pulumi.Input<number>;
    /**
     * The GreaterThan param. Value must be between 0 and 100000. Ensure that only one of the following is specified: `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`
     */
    greaterThan?: pulumi.Input<number>;
    /**
     * The Is param. Value must be between 0 and 100000. Ensure that only one of the following is specified: `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`
     */
    is?: pulumi.Input<number>;
    /**
     * The IsNot param. Value must be between 0 and 100000. Ensure that only one of the following is specified: `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`
     */
    isNot?: pulumi.Input<number>;
    /**
     * The LessEqual param. Value must be between 0 and 100000. Ensure that only one of the following is specified: `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`
     */
    lessEqual?: pulumi.Input<number>;
    /**
     * The LessThan param. Value must be between 0 and 100000. Ensure that only one of the following is specified: `greaterEqual`, `greaterThan`, `is`, `isNot`, `lessEqual`, `lessThan`
     */
    lessThan?: pulumi.Input<number>;
}
export interface HipObjectPatchManagementVendor {
    /**
     * The Name param. String length must not exceed 103 characters.
     */
    name: pulumi.Input<string>;
    /**
     * Product name. Individual elements in this list are subject to additional validation. String length must not exceed 1023 characters. String validation regex: `.*`.
     */
    products?: pulumi.Input<pulumi.Input<string>[]>;
}
export interface HttpHeaderProfileHttpHeaderInsertion {
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
    /**
     * The Types param.
     */
    types: pulumi.Input<pulumi.Input<inputs.HttpHeaderProfileHttpHeaderInsertionType>[]>;
}
export interface HttpHeaderProfileHttpHeaderInsertionType {
    /**
     * The Domains param.
     */
    domains: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Headers param.
     */
    headers: pulumi.Input<pulumi.Input<inputs.HttpHeaderProfileHttpHeaderInsertionTypeHeader>[]>;
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
}
export interface HttpHeaderProfileHttpHeaderInsertionTypeHeader {
    /**
     * The Header param.
     */
    header: pulumi.Input<string>;
    /**
     * The Log param. Default: `false`.
     */
    log?: pulumi.Input<boolean>;
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
    /**
     * The Value param.
     */
    value: pulumi.Input<string>;
}
export interface IkeCryptoProfileLifetime {
    /**
     * specify lifetime in days. Value must be between 1 and 365. Ensure that only one of the following is specified: `days`, `hours`, `minutes`, `seconds`
     */
    days?: pulumi.Input<number>;
    /**
     * specify lifetime in hours. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `hours`, `minutes`, `seconds`
     */
    hours?: pulumi.Input<number>;
    /**
     * specify lifetime in minutes. Value must be between 3 and 65535. Ensure that only one of the following is specified: `days`, `hours`, `minutes`, `seconds`
     */
    minutes?: pulumi.Input<number>;
    /**
     * specify lifetime in seconds. Value must be between 180 and 65535. Ensure that only one of the following is specified: `days`, `hours`, `minutes`, `seconds`
     */
    seconds?: pulumi.Input<number>;
}
export interface IkeGatewayAuthentication {
    /**
     * The Certificate param. Ensure that only one of the following is specified: `certificate`, `preSharedKey`
     */
    certificate?: pulumi.Input<inputs.IkeGatewayAuthenticationCertificate>;
    /**
     * The PreSharedKey param. Ensure that only one of the following is specified: `certificate`, `preSharedKey`
     */
    preSharedKey?: pulumi.Input<inputs.IkeGatewayAuthenticationPreSharedKey>;
}
export interface IkeGatewayAuthenticationCertificate {
    /**
     * The AllowIdPayloadMismatch param.
     */
    allowIdPayloadMismatch?: pulumi.Input<boolean>;
    /**
     * The CertificateProfile param.
     */
    certificateProfile?: pulumi.Input<string>;
    /**
     * The LocalCertificate param.
     */
    localCertificate?: pulumi.Input<inputs.IkeGatewayAuthenticationCertificateLocalCertificate>;
    /**
     * The StrictValidationRevocation param.
     */
    strictValidationRevocation?: pulumi.Input<boolean>;
    /**
     * The UseManagementAsSource param.
     */
    useManagementAsSource?: pulumi.Input<boolean>;
}
export interface IkeGatewayAuthenticationCertificateLocalCertificate {
    /**
     * The LocalCertificateName param.
     */
    localCertificateName?: pulumi.Input<string>;
}
export interface IkeGatewayAuthenticationPreSharedKey {
    /**
     * The Key param.
     */
    key?: pulumi.Input<string>;
}
export interface IkeGatewayLocalId {
    /**
     * Local ID string. String length must be between 1 and 1024 characters. String validation regex: `^(.+\@[a-zA-Z0-9.-]+)$|^([$a-zA-Z0-9_:.-]+)$|^(([[:xdigit:]][[:xdigit:]])+)$|^([a-zA-Z0-9.]+=(\\,|[^,])+[, ]+)*([a-zA-Z0-9.]+=(\\,|[^,])+)$`.
     */
    id?: pulumi.Input<string>;
    /**
     * The Type param.
     */
    type?: pulumi.Input<string>;
}
export interface IkeGatewayPeerAddress {
    /**
     * The DynamicAddress param. Ensure that only one of the following is specified: `dynamic`, `fqdn`, `ip`
     */
    dynamicAddress?: pulumi.Input<boolean>;
    /**
     * peer gateway FQDN name. String length must not exceed 255 characters. Ensure that only one of the following is specified: `dynamic`, `fqdn`, `ip`
     */
    fqdn?: pulumi.Input<string>;
    /**
     * peer gateway has static IP address. Ensure that only one of the following is specified: `dynamic`, `fqdn`, `ip`
     */
    ip?: pulumi.Input<string>;
}
export interface IkeGatewayPeerId {
    /**
     * Peer ID string. String length must be between 1 and 1024 characters. String validation regex: `^(.+\@[\*a-zA-Z0-9.-]+)$|^([\*$a-zA-Z0-9_:.-]+)$|^(([[:xdigit:]][[:xdigit:]])+)$|^([a-zA-Z0-9.]+=(\\,|[^,])+[, ]+)*([a-zA-Z0-9.]+=(\\,|[^,])+)$`.
     */
    id?: pulumi.Input<string>;
    /**
     * The Type param. String must be one of these: `"ipaddr"`, `"keyid"`, `"fqdn"`, `"ufqdn"`.
     */
    type?: pulumi.Input<string>;
}
export interface IkeGatewayProtocol {
    /**
     * The Ikev1 param.
     */
    ikev1?: pulumi.Input<inputs.IkeGatewayProtocolIkev1>;
    /**
     * The Ikev2 param.
     */
    ikev2?: pulumi.Input<inputs.IkeGatewayProtocolIkev2>;
    /**
     * The Version param. String must be one of these: `"ikev2-preferred"`, `"ikev1"`, `"ikev2"`. Default: `"ikev2-preferred"`.
     */
    version?: pulumi.Input<string>;
}
export interface IkeGatewayProtocolCommon {
    /**
     * The Fragmentation param.
     */
    fragmentation?: pulumi.Input<inputs.IkeGatewayProtocolCommonFragmentation>;
    /**
     * The NatTraversal param.
     */
    natTraversal?: pulumi.Input<inputs.IkeGatewayProtocolCommonNatTraversal>;
    /**
     * The PassiveMode param.
     */
    passiveMode?: pulumi.Input<boolean>;
}
export interface IkeGatewayProtocolCommonFragmentation {
    /**
     * The Enable param. Default: `false`.
     */
    enable?: pulumi.Input<boolean>;
}
export interface IkeGatewayProtocolCommonNatTraversal {
    /**
     * The Enable param.
     */
    enable?: pulumi.Input<boolean>;
}
export interface IkeGatewayProtocolIkev1 {
    /**
     * The Dpd param.
     */
    dpd?: pulumi.Input<inputs.IkeGatewayProtocolIkev1Dpd>;
    /**
     * The IkeCryptoProfile param.
     */
    ikeCryptoProfile?: pulumi.Input<string>;
}
export interface IkeGatewayProtocolIkev1Dpd {
    /**
     * The Enable param.
     */
    enable?: pulumi.Input<boolean>;
}
export interface IkeGatewayProtocolIkev2 {
    /**
     * The Dpd param.
     */
    dpd?: pulumi.Input<inputs.IkeGatewayProtocolIkev2Dpd>;
    /**
     * The IkeCryptoProfile param.
     */
    ikeCryptoProfile?: pulumi.Input<string>;
}
export interface IkeGatewayProtocolIkev2Dpd {
    /**
     * The Enable param.
     */
    enable?: pulumi.Input<boolean>;
}
export interface IpsecCryptoProfileAh {
    /**
     * The Authentications param. Individual elements in this list are subject to additional validation. String must be one of these: `"md5"`, `"sha1"`, `"sha256"`, `"sha384"`, `"sha512"`.
     */
    authentications: pulumi.Input<pulumi.Input<string>[]>;
}
export interface IpsecCryptoProfileEsp {
    /**
     * Authentication algorithm.
     */
    authentications: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Encryption algorithm. Individual elements in this list are subject to additional validation. String must be one of these: `"des"`, `"3des"`, `"aes-128-cbc"`, `"aes-192-cbc"`, `"aes-256-cbc"`, `"aes-128-gcm"`, `"aes-256-gcm"`, `"null"`.
     */
    encryptions: pulumi.Input<pulumi.Input<string>[]>;
}
export interface IpsecCryptoProfileLifesize {
    /**
     * specify lifesize in gigabytes(GB). Value must be between 1 and 65535. Ensure that only one of the following is specified: `gb`, `kb`, `mb`, `tb`
     */
    gb?: pulumi.Input<number>;
    /**
     * specify lifesize in kilobytes(KB). Value must be between 1 and 65535. Ensure that only one of the following is specified: `gb`, `kb`, `mb`, `tb`
     */
    kb?: pulumi.Input<number>;
    /**
     * specify lifesize in megabytes(MB). Value must be between 1 and 65535. Ensure that only one of the following is specified: `gb`, `kb`, `mb`, `tb`
     */
    mb?: pulumi.Input<number>;
    /**
     * specify lifesize in terabytes(TB). Value must be between 1 and 65535. Ensure that only one of the following is specified: `gb`, `kb`, `mb`, `tb`
     */
    tb?: pulumi.Input<number>;
}
export interface IpsecCryptoProfileLifetime {
    /**
     * specify lifetime in days. Value must be between 1 and 365. Ensure that only one of the following is specified: `days`, `hours`, `minutes`, `seconds`
     */
    days?: pulumi.Input<number>;
    /**
     * specify lifetime in hours. Value must be between 1 and 65535. Ensure that only one of the following is specified: `days`, `hours`, `minutes`, `seconds`
     */
    hours?: pulumi.Input<number>;
    /**
     * specify lifetime in minutes. Value must be between 3 and 65535. Ensure that only one of the following is specified: `days`, `hours`, `minutes`, `seconds`
     */
    minutes?: pulumi.Input<number>;
    /**
     * specify lifetime in seconds. Value must be between 180 and 65535. Ensure that only one of the following is specified: `days`, `hours`, `minutes`, `seconds`
     */
    seconds?: pulumi.Input<number>;
}
export interface IpsecTunnelAutoKey {
    /**
     * The IkeGateways param.
     */
    ikeGateways: pulumi.Input<pulumi.Input<inputs.IpsecTunnelAutoKeyIkeGateway>[]>;
    /**
     * The IpsecCryptoProfile param.
     */
    ipsecCryptoProfile: pulumi.Input<string>;
    /**
     * IPv6 type of proxy*id values.
     */
    proxyIdV6s?: pulumi.Input<pulumi.Input<inputs.IpsecTunnelAutoKeyProxyIdV6>[]>;
    /**
     * IPv4 type of proxy*id values.
     */
    proxyIds?: pulumi.Input<pulumi.Input<inputs.IpsecTunnelAutoKeyProxyId>[]>;
}
export interface IpsecTunnelAutoKeyIkeGateway {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
}
export interface IpsecTunnelAutoKeyProxyId {
    /**
     * The Local param.
     */
    local?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
    /**
     * The Protocol param.
     */
    protocol?: pulumi.Input<inputs.IpsecTunnelAutoKeyProxyIdProtocol>;
    /**
     * The Remote param.
     */
    remote?: pulumi.Input<string>;
}
export interface IpsecTunnelAutoKeyProxyIdProtocol {
    /**
     * IP protocol number. Value must be between 1 and 254. Ensure that only one of the following is specified: `number`, `tcp`, `udp`
     */
    number?: pulumi.Input<number>;
    /**
     * The Tcp param. Ensure that only one of the following is specified: `number`, `tcp`, `udp`
     */
    tcp?: pulumi.Input<inputs.IpsecTunnelAutoKeyProxyIdProtocolTcp>;
    /**
     * The Udp param. Ensure that only one of the following is specified: `number`, `tcp`, `udp`
     */
    udp?: pulumi.Input<inputs.IpsecTunnelAutoKeyProxyIdProtocolUdp>;
}
export interface IpsecTunnelAutoKeyProxyIdProtocolTcp {
    /**
     * The LocalPort param. Value must be between 0 and 65535. Default: `0`.
     */
    localPort?: pulumi.Input<number>;
    /**
     * The RemotePort param. Value must be between 0 and 65535. Default: `0`.
     */
    remotePort?: pulumi.Input<number>;
}
export interface IpsecTunnelAutoKeyProxyIdProtocolUdp {
    /**
     * The LocalPort param. Value must be between 0 and 65535. Default: `0`.
     */
    localPort?: pulumi.Input<number>;
    /**
     * The RemotePort param. Value must be between 0 and 65535. Default: `0`.
     */
    remotePort?: pulumi.Input<number>;
}
export interface IpsecTunnelAutoKeyProxyIdV6 {
    /**
     * The Local param.
     */
    local?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
    /**
     * The Protocol param.
     */
    protocol?: pulumi.Input<inputs.IpsecTunnelAutoKeyProxyIdV6Protocol>;
    /**
     * The Remote param.
     */
    remote?: pulumi.Input<string>;
}
export interface IpsecTunnelAutoKeyProxyIdV6Protocol {
    /**
     * IP protocol number. Value must be between 1 and 254. Ensure that only one of the following is specified: `number`, `tcp`, `udp`
     */
    number?: pulumi.Input<number>;
    /**
     * The Tcp param. Ensure that only one of the following is specified: `number`, `tcp`, `udp`
     */
    tcp?: pulumi.Input<inputs.IpsecTunnelAutoKeyProxyIdV6ProtocolTcp>;
    /**
     * The Udp param. Ensure that only one of the following is specified: `number`, `tcp`, `udp`
     */
    udp?: pulumi.Input<inputs.IpsecTunnelAutoKeyProxyIdV6ProtocolUdp>;
}
export interface IpsecTunnelAutoKeyProxyIdV6ProtocolTcp {
    /**
     * The LocalPort param. Value must be between 0 and 65535. Default: `0`.
     */
    localPort?: pulumi.Input<number>;
    /**
     * The RemotePort param. Value must be between 0 and 65535. Default: `0`.
     */
    remotePort?: pulumi.Input<number>;
}
export interface IpsecTunnelAutoKeyProxyIdV6ProtocolUdp {
    /**
     * The LocalPort param. Value must be between 0 and 65535. Default: `0`.
     */
    localPort?: pulumi.Input<number>;
    /**
     * The RemotePort param. Value must be between 0 and 65535. Default: `0`.
     */
    remotePort?: pulumi.Input<number>;
}
export interface IpsecTunnelTunnelMonitor {
    /**
     * Destination IP to send ICMP probe.
     */
    destinationIp: pulumi.Input<string>;
    /**
     * Enable tunnel monitoring on this tunnel. Default: `true`.
     */
    enable?: pulumi.Input<boolean>;
    /**
     * Which proxy-id (or proxy-id-v6) the monitoring traffic will use.
     */
    proxyId?: pulumi.Input<string>;
}
export interface KerberosServerProfileServer {
    /**
     * The Host param.
     */
    host?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Port param. Value must be between 1 and 65535.
     */
    port?: pulumi.Input<number>;
}
export interface LdapServerProfileServer {
    /**
     * The Address param.
     */
    address?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Port param. Value must be between 1 and 65535.
     */
    port?: pulumi.Input<number>;
}
export interface MfaServerMfaVendorType {
    /**
     * The DuoSecurityV2 param. Ensure that only one of the following is specified: `duoSecurityV2`, `oktaAdaptiveV1`, `pingIdentityV1`, `rsaSecuridAccessV1`
     */
    duoSecurityV2?: pulumi.Input<inputs.MfaServerMfaVendorTypeDuoSecurityV2>;
    /**
     * The OktaAdaptiveV1 param. Ensure that only one of the following is specified: `duoSecurityV2`, `oktaAdaptiveV1`, `pingIdentityV1`, `rsaSecuridAccessV1`
     */
    oktaAdaptiveV1?: pulumi.Input<inputs.MfaServerMfaVendorTypeOktaAdaptiveV1>;
    /**
     * The PingIdentityV1 param. Ensure that only one of the following is specified: `duoSecurityV2`, `oktaAdaptiveV1`, `pingIdentityV1`, `rsaSecuridAccessV1`
     */
    pingIdentityV1?: pulumi.Input<inputs.MfaServerMfaVendorTypePingIdentityV1>;
    /**
     * The RsaSecuridAccessV1 param. Ensure that only one of the following is specified: `duoSecurityV2`, `oktaAdaptiveV1`, `pingIdentityV1`, `rsaSecuridAccessV1`
     */
    rsaSecuridAccessV1?: pulumi.Input<inputs.MfaServerMfaVendorTypeRsaSecuridAccessV1>;
}
export interface MfaServerMfaVendorTypeDuoSecurityV2 {
    /**
     * The DuoApiHost param.
     */
    duoApiHost?: pulumi.Input<string>;
    /**
     * The DuoBaseuri param.
     */
    duoBaseuri?: pulumi.Input<string>;
    /**
     * The DuoIntegrationKey param.
     */
    duoIntegrationKey?: pulumi.Input<string>;
    /**
     * The DuoSecretKey param.
     */
    duoSecretKey?: pulumi.Input<string>;
    /**
     * The DuoTimeout param.
     */
    duoTimeout?: pulumi.Input<string>;
}
export interface MfaServerMfaVendorTypeOktaAdaptiveV1 {
    /**
     * The OktaApiHost param.
     */
    oktaApiHost?: pulumi.Input<string>;
    /**
     * The OktaBaseuri param.
     */
    oktaBaseuri?: pulumi.Input<string>;
    /**
     * The OktaOrg param.
     */
    oktaOrg?: pulumi.Input<string>;
    /**
     * The OktaTimeout param.
     */
    oktaTimeout?: pulumi.Input<string>;
    /**
     * The OktaToken param.
     */
    oktaToken?: pulumi.Input<string>;
}
export interface MfaServerMfaVendorTypePingIdentityV1 {
    /**
     * The PingApiHost param.
     */
    pingApiHost?: pulumi.Input<string>;
    /**
     * The PingBaseuri param.
     */
    pingBaseuri?: pulumi.Input<string>;
    /**
     * The PingOrg param.
     */
    pingOrg?: pulumi.Input<string>;
    /**
     * The PingOrgAlias param.
     */
    pingOrgAlias?: pulumi.Input<string>;
    /**
     * The PingTimeout param.
     */
    pingTimeout?: pulumi.Input<string>;
    /**
     * The PingToken param.
     */
    pingToken?: pulumi.Input<string>;
}
export interface MfaServerMfaVendorTypeRsaSecuridAccessV1 {
    /**
     * The RsaAccessid param.
     */
    rsaAccessid?: pulumi.Input<string>;
    /**
     * The RsaAccesskey param.
     */
    rsaAccesskey?: pulumi.Input<string>;
    /**
     * The RsaApiHost param.
     */
    rsaApiHost?: pulumi.Input<string>;
    /**
     * The RsaAssurancepolicyid param.
     */
    rsaAssurancepolicyid?: pulumi.Input<string>;
    /**
     * The RsaBaseuri param.
     */
    rsaBaseuri?: pulumi.Input<string>;
    /**
     * The RsaTimeout param.
     */
    rsaTimeout?: pulumi.Input<string>;
}
export interface NatRuleDestinationTranslation {
    /**
     * The DnsRewrite param.
     */
    dnsRewrite?: pulumi.Input<inputs.NatRuleDestinationTranslationDnsRewrite>;
    /**
     * The ip address to be translated. String validation regex: `^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$|^(?:[A-Fa-f0-9]{1,4}:){7}[A-Fa-f0-9]{1,4}$`.
     */
    translatedAddressSingle: pulumi.Input<string>;
    /**
     * The TranslatedPort param.
     */
    translatedPort?: pulumi.Input<number>;
}
export interface NatRuleDestinationTranslationDnsRewrite {
    /**
     * The Direction param. String must be one of these: `"reverse"`, `"forward"`. Default: `"reverse"`.
     */
    direction?: pulumi.Input<string>;
}
export interface NatRuleDynamicDestinationTranslation {
    /**
     * The Distribution param. String must be one of these: `"round-robin"`, `"source-ip-hash"`, `"ip-modulo"`, `"ip-hash"`, `"least-sessions"`. Default: `"round-robin"`.
     */
    distribution?: pulumi.Input<string>;
    /**
     * The ip address to be translated. String validation regex: `^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$|^(?:[A-Fa-f0-9]{1,4}:){7}[A-Fa-f0-9]{1,4}$`.
     */
    translatedAddressSingle: pulumi.Input<string>;
    /**
     * The TranslatedPort param.
     */
    translatedPort?: pulumi.Input<number>;
}
export interface NatRuleSourceTranslation {
    /**
     * The BiDirectional param. String must be one of these: `"yes"`, `"no"`.
     */
    biDirectional?: pulumi.Input<string>;
    /**
     * The Fallback param.
     */
    fallback?: pulumi.Input<inputs.NatRuleSourceTranslationFallback>;
    /**
     * The TranslatedAddressArray param. Ensure that only one of the following is specified: `translatedAddressArray`, `translatedAddressSingle`
     */
    translatedAddressArrays?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The TranslatedAddressSingle param. String validation regex: `^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$|^(?:[A-Fa-f0-9]{1,4}:){7}[A-Fa-f0-9]{1,4}$`. Ensure that only one of the following is specified: `translatedAddressArray`, `translatedAddressSingle`
     */
    translatedAddressSingle?: pulumi.Input<string>;
}
export interface NatRuleSourceTranslationFallback {
    /**
     * The Interface param. Ensure that only one of the following is specified: `interface`
     */
    interface?: pulumi.Input<string>;
}
export interface NatRuleTarget {
    /**
     * The Devices param.
     */
    devices?: pulumi.Input<pulumi.Input<inputs.NatRuleTargetDevice>[]>;
    /**
     * The Negate param.
     */
    negate?: pulumi.Input<boolean>;
    /**
     * The Tags param.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
}
export interface NatRuleTargetDevice {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
}
export interface QosPolicyRuleAction {
    /**
     * The Class param.
     */
    class?: pulumi.Input<string>;
}
export interface QosPolicyRuleDscpTos {
    /**
     * The Codepoints param.
     */
    codepoints?: pulumi.Input<pulumi.Input<inputs.QosPolicyRuleDscpTosCodepoint>[]>;
}
export interface QosPolicyRuleDscpTosCodepoint {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Type param.
     */
    type?: pulumi.Input<inputs.QosPolicyRuleDscpTosCodepointType>;
}
export interface QosPolicyRuleDscpTosCodepointType {
    /**
     * The Af param. Ensure that only one of the following is specified: `af`, `cs`, `custom`, `ef`, `tos`
     */
    af?: pulumi.Input<inputs.QosPolicyRuleDscpTosCodepointTypeAf>;
    /**
     * The Cs param. Ensure that only one of the following is specified: `af`, `cs`, `custom`, `ef`, `tos`
     */
    cs?: pulumi.Input<inputs.QosPolicyRuleDscpTosCodepointTypeCs>;
    /**
     * The Custom param. Ensure that only one of the following is specified: `af`, `cs`, `custom`, `ef`, `tos`
     */
    custom?: pulumi.Input<inputs.QosPolicyRuleDscpTosCodepointTypeCustom>;
    /**
     * The Ef param. Ensure that only one of the following is specified: `af`, `cs`, `custom`, `ef`, `tos`
     */
    ef?: pulumi.Input<boolean>;
    /**
     * The Tos param. Ensure that only one of the following is specified: `af`, `cs`, `custom`, `ef`, `tos`
     */
    tos?: pulumi.Input<inputs.QosPolicyRuleDscpTosCodepointTypeTos>;
}
export interface QosPolicyRuleDscpTosCodepointTypeAf {
    /**
     * The Codepoint param.
     */
    codepoint?: pulumi.Input<string>;
}
export interface QosPolicyRuleDscpTosCodepointTypeCs {
    /**
     * The Codepoint param.
     */
    codepoint?: pulumi.Input<string>;
}
export interface QosPolicyRuleDscpTosCodepointTypeCustom {
    /**
     * The Codepoint param.
     */
    codepoint?: pulumi.Input<inputs.QosPolicyRuleDscpTosCodepointTypeCustomCodepoint>;
}
export interface QosPolicyRuleDscpTosCodepointTypeCustomCodepoint {
    /**
     * The BinaryValue param.
     */
    binaryValue?: pulumi.Input<string>;
    /**
     * The CodepointName param.
     */
    codepointName?: pulumi.Input<string>;
}
export interface QosPolicyRuleDscpTosCodepointTypeTos {
    /**
     * The Codepoint param.
     */
    codepoint?: pulumi.Input<string>;
}
export interface QosProfileAggregateBandwidth {
    /**
     * guaranteed sending bandwidth in mbps. Value must be between 0 and 16000.
     */
    egressGuaranteed?: pulumi.Input<number>;
    /**
     * max sending bandwidth in mbps. Value must be between 0 and 60000.
     */
    egressMax?: pulumi.Input<number>;
}
export interface QosProfileClassBandwidthType {
    /**
     * The Mbps param. Ensure that only one of the following is specified: `mbps`, `percentage`
     */
    mbps?: pulumi.Input<inputs.QosProfileClassBandwidthTypeMbps>;
    /**
     * The Percentage param. Ensure that only one of the following is specified: `mbps`, `percentage`
     */
    percentage?: pulumi.Input<inputs.QosProfileClassBandwidthTypePercentage>;
}
export interface QosProfileClassBandwidthTypeMbps {
    /**
     * QoS setting for traffic classes.
     */
    classes?: pulumi.Input<pulumi.Input<inputs.QosProfileClassBandwidthTypeMbpsClass>[]>;
}
export interface QosProfileClassBandwidthTypeMbpsClass {
    /**
     * The ClassBandwidth param.
     */
    classBandwidth?: pulumi.Input<inputs.QosProfileClassBandwidthTypeMbpsClassClassBandwidth>;
    /**
     * Traffic class. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * traffic class priority. String must be one of these: `"real-time"`, `"high"`, `"medium"`, `"low"`. Default: `"medium"`.
     */
    priority?: pulumi.Input<string>;
}
export interface QosProfileClassBandwidthTypeMbpsClassClassBandwidth {
    /**
     * guaranteed sending bandwidth in mbps. Value must be between 0 and 60000.
     */
    egressGuaranteed?: pulumi.Input<number>;
    /**
     * max sending bandwidth in mbps. Value must be between 0 and 60000.
     */
    egressMax?: pulumi.Input<number>;
}
export interface QosProfileClassBandwidthTypePercentage {
    /**
     * QoS setting for traffic classes.
     */
    classes?: pulumi.Input<pulumi.Input<inputs.QosProfileClassBandwidthTypePercentageClass>[]>;
}
export interface QosProfileClassBandwidthTypePercentageClass {
    /**
     * The ClassBandwidth param.
     */
    classBandwidth?: pulumi.Input<inputs.QosProfileClassBandwidthTypePercentageClassClassBandwidth>;
    /**
     * Traffic class. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * traffic class priority. String must be one of these: `"real-time"`, `"high"`, `"medium"`, `"low"`. Default: `"medium"`.
     */
    priority?: pulumi.Input<string>;
}
export interface QosProfileClassBandwidthTypePercentageClassClassBandwidth {
    /**
     * guaranteed sending bandwidth in percentage. Value must be between 0 and 100.
     */
    egressGuaranteed?: pulumi.Input<number>;
    /**
     * max sending bandwidth in percentage. Value must be between 0 and 100.
     */
    egressMax?: pulumi.Input<number>;
}
export interface RadiusServerProfileProtocol {
    /**
     * The Chap param. Ensure that only one of the following is specified: `CHAP`, `EAP_TTLS_with_PAP`, `PAP`, `PEAP_MSCHAPv2`, `PEAP_with_GTC`
     */
    chap?: pulumi.Input<boolean>;
    /**
     * The EapTtlsWithPap param. Ensure that only one of the following is specified: `CHAP`, `EAP_TTLS_with_PAP`, `PAP`, `PEAP_MSCHAPv2`, `PEAP_with_GTC`
     */
    eapTtlsWithPap?: pulumi.Input<inputs.RadiusServerProfileProtocolEapTtlsWithPap>;
    /**
     * The Pap param. Ensure that only one of the following is specified: `CHAP`, `EAP_TTLS_with_PAP`, `PAP`, `PEAP_MSCHAPv2`, `PEAP_with_GTC`
     */
    pap?: pulumi.Input<boolean>;
    /**
     * The PeapMschapV2 param. Ensure that only one of the following is specified: `CHAP`, `EAP_TTLS_with_PAP`, `PAP`, `PEAP_MSCHAPv2`, `PEAP_with_GTC`
     */
    peapMschapV2?: pulumi.Input<inputs.RadiusServerProfileProtocolPeapMschapV2>;
    /**
     * The PeapWithGtc param. Ensure that only one of the following is specified: `CHAP`, `EAP_TTLS_with_PAP`, `PAP`, `PEAP_MSCHAPv2`, `PEAP_with_GTC`
     */
    peapWithGtc?: pulumi.Input<inputs.RadiusServerProfileProtocolPeapWithGtc>;
}
export interface RadiusServerProfileProtocolEapTtlsWithPap {
    /**
     * The AnonOuterId param.
     */
    anonOuterId?: pulumi.Input<boolean>;
    /**
     * The RadiusCertProfile param.
     */
    radiusCertProfile?: pulumi.Input<string>;
}
export interface RadiusServerProfileProtocolPeapMschapV2 {
    /**
     * The AllowPwdChange param.
     */
    allowPwdChange?: pulumi.Input<boolean>;
    /**
     * The AnonOuterId param.
     */
    anonOuterId?: pulumi.Input<boolean>;
    /**
     * The RadiusCertProfile param.
     */
    radiusCertProfile?: pulumi.Input<string>;
}
export interface RadiusServerProfileProtocolPeapWithGtc {
    /**
     * The AnonOuterId param.
     */
    anonOuterId?: pulumi.Input<boolean>;
    /**
     * The RadiusCertProfile param.
     */
    radiusCertProfile?: pulumi.Input<string>;
}
export interface RadiusServerProfileServer {
    /**
     * The IpAddress param.
     */
    ipAddress?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Port param. Value must be between 1 and 65535.
     */
    port?: pulumi.Input<number>;
    /**
     * The Secret param. String length must not exceed 64 characters.
     */
    secret?: pulumi.Input<string>;
}
export interface RegionGeoLocation {
    /**
     * latitude coordinate. Value must be between -90 and 90.
     */
    latitude: pulumi.Input<number>;
    /**
     * longitude coordinate. Value must be between -180 and 180.
     */
    longitude: pulumi.Input<number>;
}
export interface RemoteNetworkEcmpTunnel {
    /**
     * The IpsecTunnel param.
     */
    ipsecTunnel: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
    /**
     * The Protocol param.
     */
    protocol: pulumi.Input<inputs.RemoteNetworkEcmpTunnelProtocol>;
}
export interface RemoteNetworkEcmpTunnelProtocol {
    /**
     * The Bgp param.
     */
    bgp?: pulumi.Input<inputs.RemoteNetworkEcmpTunnelProtocolBgp>;
}
export interface RemoteNetworkEcmpTunnelProtocolBgp {
    /**
     * The DoNotExportRoutes param.
     */
    doNotExportRoutes?: pulumi.Input<boolean>;
    /**
     * to setup bgp protocol, enable need to set as true.
     */
    enable?: pulumi.Input<boolean>;
    /**
     * The LocalIpAddress param.
     */
    localIpAddress?: pulumi.Input<string>;
    /**
     * The OriginateDefaultRoute param.
     */
    originateDefaultRoute?: pulumi.Input<boolean>;
    /**
     * The PeerAs param.
     */
    peerAs?: pulumi.Input<string>;
    /**
     * The PeerIpAddress param.
     */
    peerIpAddress?: pulumi.Input<string>;
    /**
     * Exchange Routes: exchange-v4-over-v4 stands for Exchange IPv4 routes over IPv4 peering. exchange-v4-v6-over-v4 stands for Exchange both IPv4 and IPv6 routes over IPv4 peering. exchange-v4-over-v4-v6-over-v6 stands for Exchange IPv4 routes over IPv4 peer and IPv6 route over IPv6 peer. exchange-v6-over-v6 stands for Exchange IPv6 routes over IPv6 peering. String must be one of these: `"exchange-v4-over-v4"`, `"exchange-v4-v6-over-v4"`, `"exchange-v4-over-v4-v6-over-v6"`, `"exchange-v6-over-v6"`.
     */
    peeringType?: pulumi.Input<string>;
    /**
     * The Secret param.
     */
    secret?: pulumi.Input<string>;
    /**
     * The SummarizeMobileUserRoutes param.
     */
    summarizeMobileUserRoutes?: pulumi.Input<boolean>;
}
export interface RemoteNetworkProtocol {
    /**
     * The Bgp param.
     */
    bgp?: pulumi.Input<inputs.RemoteNetworkProtocolBgp>;
    /**
     * secondary bgp routing as bgp*peer.
     */
    bgpPeer?: pulumi.Input<inputs.RemoteNetworkProtocolBgpPeer>;
}
export interface RemoteNetworkProtocolBgp {
    /**
     * The DoNotExportRoutes param.
     */
    doNotExportRoutes?: pulumi.Input<boolean>;
    /**
     * to setup bgp protocol, enable need to set as true.
     */
    enable?: pulumi.Input<boolean>;
    /**
     * The LocalIpAddress param.
     */
    localIpAddress?: pulumi.Input<string>;
    /**
     * The OriginateDefaultRoute param.
     */
    originateDefaultRoute?: pulumi.Input<boolean>;
    /**
     * The PeerAs param.
     */
    peerAs?: pulumi.Input<string>;
    /**
     * The PeerIpAddress param.
     */
    peerIpAddress?: pulumi.Input<string>;
    /**
     * Exchange Routes: exchange-v4-over-v4 stands for Exchange IPv4 routes over IPv4 peering. exchange-v4-v6-over-v4 stands for Exchange both IPv4 and IPv6 routes over IPv4 peering. exchange-v4-over-v4-v6-over-v6 stands for Exchange IPv4 routes over IPv4 peer and IPv6 route over IPv6 peer. exchange-v6-over-v6 stands for Exchange IPv6 routes over IPv6 peering. String must be one of these: `"exchange-v4-over-v4"`, `"exchange-v4-v6-over-v4"`, `"exchange-v4-over-v4-v6-over-v6"`, `"exchange-v6-over-v6"`.
     */
    peeringType?: pulumi.Input<string>;
    /**
     * The Secret param.
     */
    secret?: pulumi.Input<string>;
    /**
     * The SummarizeMobileUserRoutes param.
     */
    summarizeMobileUserRoutes?: pulumi.Input<boolean>;
}
export interface RemoteNetworkProtocolBgpPeer {
    /**
     * The LocalIpAddress param.
     */
    localIpAddress?: pulumi.Input<string>;
    /**
     * The PeerIpAddress param.
     */
    peerIpAddress?: pulumi.Input<string>;
    /**
     * If true, the secondary BGP peer configuration will be the same as the primary BGP peer. Default: `true`.
     */
    sameAsPrimary?: pulumi.Input<boolean>;
    /**
     * The Secret param.
     */
    secret?: pulumi.Input<string>;
}
export interface ScepProfileAlgorithm {
    /**
     * The Rsa param.
     */
    rsa?: pulumi.Input<inputs.ScepProfileAlgorithmRsa>;
}
export interface ScepProfileAlgorithmRsa {
    /**
     * The RsaNbits param.
     */
    rsaNbits?: pulumi.Input<string>;
}
export interface ScepProfileCertificateAttributes {
    /**
     * The Dnsname param. Ensure that only one of the following is specified: `dnsname`, `rfc822name`, `uniformResourceIdentifier`
     */
    dnsname?: pulumi.Input<string>;
    /**
     * The Rfc822name param. Ensure that only one of the following is specified: `dnsname`, `rfc822name`, `uniformResourceIdentifier`
     */
    rfc822name?: pulumi.Input<string>;
    /**
     * The UniformResourceIdentifier param. Ensure that only one of the following is specified: `dnsname`, `rfc822name`, `uniformResourceIdentifier`
     */
    uniformResourceIdentifier?: pulumi.Input<string>;
}
export interface ScepProfileScepChallenge {
    /**
     * The DynamicChallenge param. Ensure that only one of the following is specified: `dynamic`, `fixed`, `none`
     */
    dynamicChallenge?: pulumi.Input<inputs.ScepProfileScepChallengeDynamicChallenge>;
    /**
     * Challenge to use for SCEP server on mobile clients. String length must not exceed 1024 characters. Ensure that only one of the following is specified: `dynamic`, `fixed`, `none`
     */
    fixed?: pulumi.Input<string>;
    /**
     * The None param. String must be one of these: `""`. Ensure that only one of the following is specified: `dynamic`, `fixed`, `none`
     */
    none?: pulumi.Input<string>;
}
export interface ScepProfileScepChallengeDynamicChallenge {
    /**
     * The OtpServerUrl param. String length must not exceed 255 characters.
     */
    otpServerUrl?: pulumi.Input<string>;
    /**
     * The Password param. String length must not exceed 255 characters.
     */
    password?: pulumi.Input<string>;
    /**
     * The Username param. String length must not exceed 255 characters.
     */
    username?: pulumi.Input<string>;
}
export interface ScheduleScheduleType {
    /**
     * The NonRecurringList param. Individual elements in this list are subject to additional validation. String length must be between 33 and 33 characters. String validation regex: `[0-9][0-9][0-9][0-9]\/([0][1-9]|[1][0-2])\/([0-2][0-9]|[3][0-1])@([01][0-9]|[2][0-3]):([0-5][0-9])-[0-9][0-9][0-9][0-9]\/([0][1-9]|[1][0-2])\/([0-2][0-9]|[3][0-1])@([01][0-9]|[2][0-3]):([0-5][0-9])`. Ensure that only one of the following is specified: `nonRecurring`, `recurring`
     */
    nonRecurringLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Recurring param. Ensure that only one of the following is specified: `nonRecurring`, `recurring`
     */
    recurring?: pulumi.Input<inputs.ScheduleScheduleTypeRecurring>;
}
export interface ScheduleScheduleTypeRecurring {
    /**
     * The DailyList param. Individual elements in this list are subject to additional validation. String length must be between 11 and 11 characters. String validation regex: `([01][0-9]|[2][0-3]):([0-5][0-9])-([01][0-9]|[2][0-3]):([0-5][0-9])`. Ensure that only one of the following is specified: `daily`, `weekly`
     */
    dailyLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Weekly param. Ensure that only one of the following is specified: `daily`, `weekly`
     */
    weekly?: pulumi.Input<inputs.ScheduleScheduleTypeRecurringWeekly>;
}
export interface ScheduleScheduleTypeRecurringWeekly {
    /**
     * The FridayList param. Individual elements in this list are subject to additional validation. String length must be between 11 and 11 characters. String validation regex: `([01][0-9]|[2][0-3]):([0-5][0-9])-([01][0-9]|[2][0-3]):([0-5][0-9])`.
     */
    fridayLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The MondayList param. Individual elements in this list are subject to additional validation. String length must be between 11 and 11 characters. String validation regex: `([01][0-9]|[2][0-3]):([0-5][0-9])-([01][0-9]|[2][0-3]):([0-5][0-9])`.
     */
    mondayLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The SaturdayList param. Individual elements in this list are subject to additional validation. String length must be between 11 and 11 characters. String validation regex: `([01][0-9]|[2][0-3]):([0-5][0-9])-([01][0-9]|[2][0-3]):([0-5][0-9])`.
     */
    saturdayLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The SundayList param. Individual elements in this list are subject to additional validation. String length must be between 11 and 11 characters. String validation regex: `([01][0-9]|[2][0-3]):([0-5][0-9])-([01][0-9]|[2][0-3]):([0-5][0-9])`.
     */
    sundayLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ThursdayList param. Individual elements in this list are subject to additional validation. String length must be between 11 and 11 characters. String validation regex: `([01][0-9]|[2][0-3]):([0-5][0-9])-([01][0-9]|[2][0-3]):([0-5][0-9])`.
     */
    thursdayLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The TuesdayList param. Individual elements in this list are subject to additional validation. String length must be between 11 and 11 characters. String validation regex: `([01][0-9]|[2][0-3]):([0-5][0-9])-([01][0-9]|[2][0-3]):([0-5][0-9])`.
     */
    tuesdayLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The WednesdayList param. Individual elements in this list are subject to additional validation. String length must be between 11 and 11 characters. String validation regex: `([01][0-9]|[2][0-3]):([0-5][0-9])-([01][0-9]|[2][0-3]):([0-5][0-9])`.
     */
    wednesdayLists?: pulumi.Input<pulumi.Input<string>[]>;
}
export interface SecurityRuleProfileSetting {
    /**
     * The security profile group.
     */
    groups?: pulumi.Input<pulumi.Input<string>[]>;
}
export interface ServiceConnectionBgpPeer {
    /**
     * The LocalIpAddress param.
     */
    localIpAddress?: pulumi.Input<string>;
    /**
     * The LocalIpv6Address param.
     */
    localIpv6Address?: pulumi.Input<string>;
    /**
     * The PeerIpAddress param.
     */
    peerIpAddress?: pulumi.Input<string>;
    /**
     * The PeerIpv6Address param.
     */
    peerIpv6Address?: pulumi.Input<string>;
    /**
     * The SameAsPrimary param.
     */
    sameAsPrimary?: pulumi.Input<boolean>;
    /**
     * The Secret param.
     */
    secret?: pulumi.Input<string>;
}
export interface ServiceConnectionProtocol {
    /**
     * The Bgp param.
     */
    bgp?: pulumi.Input<inputs.ServiceConnectionProtocolBgp>;
}
export interface ServiceConnectionProtocolBgp {
    /**
     * The DoNotExportRoutes param.
     */
    doNotExportRoutes?: pulumi.Input<boolean>;
    /**
     * The Enable param.
     */
    enable?: pulumi.Input<boolean>;
    /**
     * The FastFailover param.
     */
    fastFailover?: pulumi.Input<boolean>;
    /**
     * The LocalIpAddress param.
     */
    localIpAddress?: pulumi.Input<string>;
    /**
     * The OriginateDefaultRoute param.
     */
    originateDefaultRoute?: pulumi.Input<boolean>;
    /**
     * The PeerAs param.
     */
    peerAs?: pulumi.Input<string>;
    /**
     * The PeerIpAddress param.
     */
    peerIpAddress?: pulumi.Input<string>;
    /**
     * The Secret param.
     */
    secret?: pulumi.Input<string>;
    /**
     * The SummarizeMobileUserRoutes param.
     */
    summarizeMobileUserRoutes?: pulumi.Input<boolean>;
}
export interface ServiceConnectionQos {
    /**
     * The Enable param.
     */
    enable?: pulumi.Input<boolean>;
    /**
     * The QosProfile param.
     */
    qosProfile?: pulumi.Input<string>;
}
export interface ServiceProtocol {
    /**
     * The Tcp param. Ensure that only one of the following is specified: `tcp`, `udp`
     */
    tcp?: pulumi.Input<inputs.ServiceProtocolTcp>;
    /**
     * The Udp param. Ensure that only one of the following is specified: `tcp`, `udp`
     */
    udp?: pulumi.Input<inputs.ServiceProtocolUdp>;
}
export interface ServiceProtocolTcp {
    /**
     * The Override param.
     */
    override?: pulumi.Input<inputs.ServiceProtocolTcpOverride>;
    /**
     * The Port param. String length must be between 1 and 1023 characters.
     */
    port: pulumi.Input<string>;
    /**
     * The SourcePort param. String length must be between 1 and 1023 characters.
     */
    sourcePort?: pulumi.Input<string>;
}
export interface ServiceProtocolTcpOverride {
    /**
     * tcp session half-close timeout value (in second). Value must be between 1 and 604800. Default: `120`.
     */
    halfcloseTimeout?: pulumi.Input<number>;
    /**
     * tcp session timeout value (in second). Value must be between 1 and 604800. Default: `3600`.
     */
    timeout?: pulumi.Input<number>;
    /**
     * tcp session time-wait timeout value (in second). Value must be between 1 and 600. Default: `15`.
     */
    timewaitTimeout?: pulumi.Input<number>;
}
export interface ServiceProtocolUdp {
    /**
     * The Override param.
     */
    override?: pulumi.Input<inputs.ServiceProtocolUdpOverride>;
    /**
     * The Port param. String length must be between 1 and 1023 characters.
     */
    port: pulumi.Input<string>;
    /**
     * The SourcePort param. String length must be between 1 and 1023 characters.
     */
    sourcePort?: pulumi.Input<string>;
}
export interface ServiceProtocolUdpOverride {
    /**
     * udp session timeout value (in second). Value must be between 1 and 604800. Default: `30`.
     */
    timeout?: pulumi.Input<number>;
}
export interface SnippetFolder {
    /**
     * The Id param.
     */
    id?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
}
export interface TacacsServerProfileServer {
    /**
     * The Address param.
     */
    address?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Port param. Value must be between 1 and 65535.
     */
    port?: pulumi.Input<number>;
    /**
     * The Secret param. String length must not exceed 64 characters.
     */
    secret?: pulumi.Input<string>;
}
export interface TlsServiceProfileProtocolSettings {
    /**
     * Allow authentication SHA1.
     */
    authAlgoSha1?: pulumi.Input<boolean>;
    /**
     * Allow authentication SHA256.
     */
    authAlgoSha256?: pulumi.Input<boolean>;
    /**
     * Allow authentication SHA384.
     */
    authAlgoSha384?: pulumi.Input<boolean>;
    /**
     * Allow algorithm 3DES.
     */
    encAlgo3des?: pulumi.Input<boolean>;
    /**
     * Allow algorithm AES-128-CBC.
     */
    encAlgoAes128Cbc?: pulumi.Input<boolean>;
    /**
     * Allow algorithm AES-128-GCM.
     */
    encAlgoAes128Gcm?: pulumi.Input<boolean>;
    /**
     * Allow algorithm AES-256-CBC.
     */
    encAlgoAes256Cbc?: pulumi.Input<boolean>;
    /**
     * Allow algorithm AES-256-GCM.
     */
    encAlgoAes256Gcm?: pulumi.Input<boolean>;
    /**
     * Allow algorithm RC4.
     */
    encAlgoRc4?: pulumi.Input<boolean>;
    /**
     * Allow algorithm DHE.
     */
    keyxchgAlgoDhe?: pulumi.Input<boolean>;
    /**
     * Allow algorithm ECDHE.
     */
    keyxchgAlgoEcdhe?: pulumi.Input<boolean>;
    /**
     * Allow algorithm RSA.
     */
    keyxchgAlgoRsa?: pulumi.Input<boolean>;
    /**
     * The MaxVersion param. String must be one of these: `"tls1-0"`, `"tls1-1"`, `"tls1-2"`, `"tls1-3"`, `"max"`. Default: `"max"`.
     */
    maxVersion?: pulumi.Input<string>;
    /**
     * The MinVersion param. String must be one of these: `"tls1-0"`, `"tls1-1"`, `"tls1-2"`. Default: `"tls1-0"`.
     */
    minVersion?: pulumi.Input<string>;
}
export interface TrafficSteeringRuleAction {
    /**
     * The Forward param. Ensure that only one of the following is specified: `forward`, `no-pbf`
     */
    forward?: pulumi.Input<inputs.TrafficSteeringRuleActionForward>;
    /**
     * The NoPbf param. Ensure that only one of the following is specified: `forward`, `no-pbf`
     */
    noPbf?: pulumi.Input<boolean>;
}
export interface TrafficSteeringRuleActionForward {
    /**
     * The Target param.
     */
    target?: pulumi.Input<string>;
}
export interface UrlAccessProfileCredentialEnforcement {
    /**
     * The Alerts param.
     */
    alerts?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Allows param.
     */
    allows?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Blocks param.
     */
    blocks?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Continues param.
     */
    continues?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The LogSeverity param. Default: `"medium"`.
     */
    logSeverity?: pulumi.Input<string>;
    /**
     * The Mode param.
     */
    mode?: pulumi.Input<inputs.UrlAccessProfileCredentialEnforcementMode>;
}
export interface UrlAccessProfileCredentialEnforcementMode {
    /**
     * The Disabled param. Default: `false`.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * The DomainCredentials param. Default: `false`.
     */
    domainCredentials?: pulumi.Input<boolean>;
    /**
     * The GroupMapping param.
     */
    groupMapping?: pulumi.Input<string>;
    /**
     * The IpUser param. Default: `false`.
     */
    ipUser?: pulumi.Input<boolean>;
}
export interface VulnerabilityProtectionProfileRule {
    /**
     * The Action param.
     */
    action?: pulumi.Input<inputs.VulnerabilityProtectionProfileRuleAction>;
    /**
     * The Category param. String must be one of these: `"any"`, `"brute-force"`, `"code-execution"`, `"code-obfuscation"`, `"command-execution"`, `"dos"`, `"exploit-kit"`, `"info-leak"`, `"insecure-credentials"`, `"overflow"`, `"phishing"`, `"protocol-anomaly"`, `"scan"`, `"sql-injection"`.
     */
    category?: pulumi.Input<string>;
    /**
     * The Cves param.
     */
    cves?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Host param.
     */
    host?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The PacketCapture param. String must be one of these: `"disable"`, `"single-packet"`, `"extended-capture"`.
     */
    packetCapture?: pulumi.Input<string>;
    /**
     * The Severities param.
     */
    severities?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The ThreatName param.
     */
    threatName?: pulumi.Input<string>;
    /**
     * The VendorIds param.
     */
    vendorIds?: pulumi.Input<pulumi.Input<string>[]>;
}
export interface VulnerabilityProtectionProfileRuleAction {
    /**
     * The Alert param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    alert?: pulumi.Input<boolean>;
    /**
     * The Allow param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    allow?: pulumi.Input<boolean>;
    /**
     * The BlockIp param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    blockIp?: pulumi.Input<inputs.VulnerabilityProtectionProfileRuleActionBlockIp>;
    /**
     * The Default param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    default?: pulumi.Input<boolean>;
    /**
     * The Drop param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    drop?: pulumi.Input<boolean>;
    /**
     * The ResetBoth param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetBoth?: pulumi.Input<boolean>;
    /**
     * The ResetClient param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetClient?: pulumi.Input<boolean>;
    /**
     * The ResetServer param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetServer?: pulumi.Input<boolean>;
}
export interface VulnerabilityProtectionProfileRuleActionBlockIp {
    /**
     * The Duration param. Value must be between 1 and 3600.
     */
    duration?: pulumi.Input<number>;
    /**
     * The TrackBy param. String must be one of these: `"source-and-destination"`, `"source"`.
     */
    trackBy?: pulumi.Input<string>;
}
export interface VulnerabilityProtectionProfileThreatException {
    /**
     * The Action param.
     */
    action?: pulumi.Input<inputs.VulnerabilityProtectionProfileThreatExceptionAction>;
    /**
     * The ExemptIps param.
     */
    exemptIps?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionProfileThreatExceptionExemptIp>[]>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Notes param.
     */
    notes?: pulumi.Input<string>;
    /**
     * The PacketCapture param. String must be one of these: `"disable"`, `"single-packet"`, `"extended-capture"`.
     */
    packetCapture?: pulumi.Input<string>;
    /**
     * The TimeAttribute param.
     */
    timeAttribute?: pulumi.Input<inputs.VulnerabilityProtectionProfileThreatExceptionTimeAttribute>;
}
export interface VulnerabilityProtectionProfileThreatExceptionAction {
    /**
     * The Alert param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    alert?: pulumi.Input<boolean>;
    /**
     * The Allow param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    allow?: pulumi.Input<boolean>;
    /**
     * The BlockIp param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    blockIp?: pulumi.Input<inputs.VulnerabilityProtectionProfileThreatExceptionActionBlockIp>;
    /**
     * The Default param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    default?: pulumi.Input<boolean>;
    /**
     * The Drop param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    drop?: pulumi.Input<boolean>;
    /**
     * The ResetBoth param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetBoth?: pulumi.Input<boolean>;
    /**
     * The ResetClient param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetClient?: pulumi.Input<boolean>;
    /**
     * The ResetServer param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `default`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetServer?: pulumi.Input<boolean>;
}
export interface VulnerabilityProtectionProfileThreatExceptionActionBlockIp {
    /**
     * The Duration param. Value must be between 1 and 3600.
     */
    duration?: pulumi.Input<number>;
    /**
     * The TrackBy param. String must be one of these: `"source-and-destination"`, `"source"`.
     */
    trackBy?: pulumi.Input<string>;
}
export interface VulnerabilityProtectionProfileThreatExceptionExemptIp {
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
}
export interface VulnerabilityProtectionProfileThreatExceptionTimeAttribute {
    /**
     * The Interval param. Value must be between 1 and 3600.
     */
    interval?: pulumi.Input<number>;
    /**
     * The Threshold param. Value must be between 1 and 65535.
     */
    threshold?: pulumi.Input<number>;
    /**
     * The TrackBy param. String must be one of these: `"source"`, `"destination"`, `"source-and-destination"`.
     */
    trackBy?: pulumi.Input<string>;
}
export interface VulnerabilityProtectionSignaturesAffectedHost {
    /**
     * The Client param. Ensure that only one of the following is specified: `client`, `server`
     */
    client?: pulumi.Input<boolean>;
    /**
     * The Server param. Ensure that only one of the following is specified: `client`, `server`
     */
    server?: pulumi.Input<boolean>;
}
export interface VulnerabilityProtectionSignaturesDefaultAction {
    /**
     * The Alert param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    alert?: pulumi.Input<boolean>;
    /**
     * The Allow param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    allow?: pulumi.Input<boolean>;
    /**
     * The BlockIp param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    blockIp?: pulumi.Input<inputs.VulnerabilityProtectionSignaturesDefaultActionBlockIp>;
    /**
     * The Drop param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    drop?: pulumi.Input<boolean>;
    /**
     * The ResetBoth param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetBoth?: pulumi.Input<boolean>;
    /**
     * The ResetClient param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetClient?: pulumi.Input<boolean>;
    /**
     * The ResetServer param. Ensure that only one of the following is specified: `alert`, `allow`, `blockIp`, `drop`, `resetBoth`, `resetClient`, `resetServer`
     */
    resetServer?: pulumi.Input<boolean>;
}
export interface VulnerabilityProtectionSignaturesDefaultActionBlockIp {
    /**
     * The Duration param. Value must be between 1 and 3600.
     */
    duration?: pulumi.Input<number>;
    /**
     * The TrackBy param. String must be one of these: `"source-and-destination"`, `"source"`.
     */
    trackBy?: pulumi.Input<string>;
}
export interface VulnerabilityProtectionSignaturesSignature {
    /**
     * The Combination param. Ensure that only one of the following is specified: `combination`, `standard`
     */
    combination?: pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureCombination>;
    /**
     * The Standards param. Ensure that only one of the following is specified: `combination`, `standard`
     */
    standards?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureStandard>[]>;
}
export interface VulnerabilityProtectionSignaturesSignatureCombination {
    /**
     * The AndConditions param.
     */
    andConditions?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureCombinationAndCondition>[]>;
    /**
     * The OrderFree param. Default: `false`.
     */
    orderFree?: pulumi.Input<boolean>;
    /**
     * The TimeAttribute param.
     */
    timeAttribute?: pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureCombinationTimeAttribute>;
}
export interface VulnerabilityProtectionSignaturesSignatureCombinationAndCondition {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The OrConditions param.
     */
    orConditions?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureCombinationAndConditionOrCondition>[]>;
}
export interface VulnerabilityProtectionSignaturesSignatureCombinationAndConditionOrCondition {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The ThreatId param.
     */
    threatId?: pulumi.Input<string>;
}
export interface VulnerabilityProtectionSignaturesSignatureCombinationTimeAttribute {
    /**
     * The Interval param. Value must be between 1 and 3600.
     */
    interval?: pulumi.Input<number>;
    /**
     * The Threshold param. Value must be between 1 and 255.
     */
    threshold?: pulumi.Input<number>;
    /**
     * The TrackBy param. String must be one of these: `"source-and-destination"`, `"source"`, `"destination"`.
     */
    trackBy?: pulumi.Input<string>;
}
export interface VulnerabilityProtectionSignaturesSignatureStandard {
    /**
     * The AndConditions param.
     */
    andConditions?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureStandardAndCondition>[]>;
    /**
     * The Comment param. String length must not exceed 256 characters.
     */
    comment?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name: pulumi.Input<string>;
    /**
     * The OrderFree param. Default: `false`.
     */
    orderFree?: pulumi.Input<boolean>;
    /**
     * The Scope param. String must be one of these: `"protocol-data-unit"`, `"session"`.
     */
    scope?: pulumi.Input<string>;
}
export interface VulnerabilityProtectionSignaturesSignatureStandardAndCondition {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The OrConditions param.
     */
    orConditions?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrCondition>[]>;
}
export interface VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrCondition {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Operator param.
     */
    operator?: pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperator>;
}
export interface VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperator {
    /**
     * The EqualTo param.
     */
    equalTo?: pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorEqualTo>;
    /**
     * The GreaterThan param.
     */
    greaterThan?: pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorGreaterThan>;
    /**
     * The LessThan param.
     */
    lessThan?: pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorLessThan>;
    /**
     * The PatternMatch param.
     */
    patternMatch?: pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorPatternMatch>;
}
export interface VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorEqualTo {
    /**
     * The Context param.
     */
    context?: pulumi.Input<string>;
    /**
     * The Negate param. Default: `false`.
     */
    negate?: pulumi.Input<boolean>;
    /**
     * The Qualifiers param.
     */
    qualifiers?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorEqualToQualifier>[]>;
    /**
     * The Value param. Value must be between 0 and 4294967295.
     */
    value?: pulumi.Input<number>;
}
export interface VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorEqualToQualifier {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Value param.
     */
    value?: pulumi.Input<string>;
}
export interface VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorGreaterThan {
    /**
     * The Context param.
     */
    context?: pulumi.Input<string>;
    /**
     * The Qualifiers param.
     */
    qualifiers?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorGreaterThanQualifier>[]>;
    /**
     * The Value param. Value must be between 0 and 4294967295.
     */
    value?: pulumi.Input<number>;
}
export interface VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorGreaterThanQualifier {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Value param.
     */
    value?: pulumi.Input<string>;
}
export interface VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorLessThan {
    /**
     * The Context param.
     */
    context?: pulumi.Input<string>;
    /**
     * The Qualifiers param.
     */
    qualifiers?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorLessThanQualifier>[]>;
    /**
     * The Value param. Value must be between 0 and 4294967295.
     */
    value?: pulumi.Input<number>;
}
export interface VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorLessThanQualifier {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Value param.
     */
    value?: pulumi.Input<string>;
}
export interface VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorPatternMatch {
    /**
     * The Context param.
     */
    context?: pulumi.Input<string>;
    /**
     * The Negate param. Default: `false`.
     */
    negate?: pulumi.Input<boolean>;
    /**
     * The Pattern param.
     */
    pattern?: pulumi.Input<string>;
    /**
     * The Qualifiers param.
     */
    qualifiers?: pulumi.Input<pulumi.Input<inputs.VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorPatternMatchQualifier>[]>;
}
export interface VulnerabilityProtectionSignaturesSignatureStandardAndConditionOrConditionOperatorPatternMatchQualifier {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Value param.
     */
    value?: pulumi.Input<string>;
}
export interface WildfireAntiVirusProfileMlavException {
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Filename param.
     */
    filename?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
}
export interface WildfireAntiVirusProfileRule {
    /**
     * The Analysis param. String must be one of these: `"public-cloud"`, `"private-cloud"`.
     */
    analysis?: pulumi.Input<string>;
    /**
     * The Applications param.
     */
    applications?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Direction param. String must be one of these: `"download"`, `"upload"`, `"both"`.
     */
    direction?: pulumi.Input<string>;
    /**
     * The FileTypes param.
     */
    fileTypes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
}
export interface WildfireAntiVirusProfileThreatException {
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Notes param.
     */
    notes?: pulumi.Input<string>;
}
